# coding: utf-8

"""
    (v2.0) Dynamics 365 Business Central

    (v2.0) Business Central Standard APIs

    The version of the OpenAPI document: 2.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from pybusinesscentral.model.company import Company

class TestCompany(unittest.TestCase):
    """Company unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> Company:
        """Test Company
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `Company`
        """
        model = Company()
        if include_optional:
            return Company(
                id = '',
                system_version = '',
                name = '',
                display_name = '',
                business_profile_id = '',
                items = [
                    pybusinesscentral.model.item.item(
                        id = '', 
                        number = '', 
                        display_name = '', 
                        type = '', 
                        item_category_id = '', 
                        item_category_code = '', 
                        blocked = True, 
                        base_unit_of_measure_id = '', 
                        base_unit_of_measure = pybusinesscentral.model.unitofmeasuretype.unitofmeasuretype(
                            code = '', 
                            display_name = '', 
                            symbol = '', 
                            unit_conversion = pybusinesscentral.model.itemunitofmeasureconversiontype.itemunitofmeasureconversiontype(
                                to_unit_of_measure = '', 
                                from_to_conversion_rate = 1.337, 
                                picture = [
                                    pybusinesscentral.model.picture.picture(
                                        id = '', 
                                        width = 56, 
                                        height = 56, 
                                        content_type = '', 
                                        content@odata/media_edit_link = '', 
                                        content@odata/media_read_link = '', )
                                    ], 
                                default_dimensions = [
                                    pybusinesscentral.model.default_dimensions.defaultDimensions(
                                        parent_id = '', 
                                        dimension_id = '', 
                                        dimension_code = '', 
                                        dimension_value_id = '', 
                                        dimension_value_code = '', 
                                        posting_validation = '', 
                                        account = pybusinesscentral.model.account.account(
                                            id = '', 
                                            number = '', 
                                            display_name = '', 
                                            category = '', 
                                            sub_category = '', 
                                            blocked = True, 
                                            last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), 
                                        dimension = pybusinesscentral.model.dimension.dimension(
                                            id = '', 
                                            code = '', 
                                            display_name = '', 
                                            last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                            dimension_values = [
                                                pybusinesscentral.model.dimension_value.dimensionValue(
                                                    id = '', 
                                                    code = '', 
                                                    display_name = '', 
                                                    last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                                                ], ), 
                                        dimension_value = pybusinesscentral.model.dimension_value.dimensionValue(
                                            id = '', 
                                            code = '', 
                                            display_name = '', 
                                            last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), )
                                    ], 
                                item_category = pybusinesscentral.model.item_category.itemCategory(
                                    id = '', 
                                    code = '', 
                                    display_name = '', 
                                    last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), ), 
                            picture = [
                                pybusinesscentral.model.picture.picture(
                                    id = '', 
                                    width = 56, 
                                    height = 56, 
                                    content_type = '', 
                                    content@odata/media_edit_link = '', 
                                    content@odata/media_read_link = '', )
                                ], 
                            default_dimensions = [
                                pybusinesscentral.model.default_dimensions.defaultDimensions(
                                    parent_id = '', 
                                    dimension_id = '', 
                                    dimension_code = '', 
                                    dimension_value_id = '', 
                                    dimension_value_code = '', 
                                    posting_validation = '', )
                                ], 
                            item_category = pybusinesscentral.model.item_category.itemCategory(
                                id = '', 
                                code = '', 
                                display_name = '', 
                                last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), ), 
                        gtin = '', 
                        inventory = 1.337, 
                        unit_price = 1.337, 
                        price_includes_tax = True, 
                        unit_cost = 1.337, 
                        tax_group_id = '', 
                        tax_group_code = '', 
                        last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        picture = , 
                        default_dimensions = , 
                        item_category = , )
                    ],
                picture = [
                    pybusinesscentral.model.picture.picture(
                        id = '', 
                        width = 56, 
                        height = 56, 
                        content_type = '', 
                        content@odata/media_edit_link = '', 
                        content@odata/media_read_link = '', )
                    ],
                default_dimensions = [
                    pybusinesscentral.model.default_dimensions.defaultDimensions(
                        parent_id = '', 
                        dimension_id = '', 
                        dimension_code = '', 
                        dimension_value_id = '', 
                        dimension_value_code = '', 
                        posting_validation = '', 
                        account = pybusinesscentral.model.account.account(
                            id = '', 
                            number = '', 
                            display_name = '', 
                            category = '', 
                            sub_category = '', 
                            blocked = True, 
                            last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), 
                        dimension = pybusinesscentral.model.dimension.dimension(
                            id = '', 
                            code = '', 
                            display_name = '', 
                            last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            dimension_values = [
                                pybusinesscentral.model.dimension_value.dimensionValue(
                                    id = '', 
                                    code = '', 
                                    display_name = '', 
                                    last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                                ], ), 
                        dimension_value = pybusinesscentral.model.dimension_value.dimensionValue(
                            id = '', 
                            code = '', 
                            display_name = '', 
                            last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), )
                    ],
                customers = [
                    pybusinesscentral.model.customer.customer(
                        id = '', 
                        number = '', 
                        display_name = '', 
                        type = '', 
                        address_line1 = '', 
                        address_line2 = '', 
                        city = '', 
                        state = '', 
                        country = '', 
                        postal_code = '', 
                        phone_number = '', 
                        email = '', 
                        website = '', 
                        tax_liable = True, 
                        tax_area_id = '', 
                        tax_area_display_name = '', 
                        tax_registration_number = '', 
                        currency_id = '', 
                        currency_code = '', 
                        payment_terms_id = '', 
                        shipment_method_id = '', 
                        payment_method_id = '', 
                        blocked = '', 
                        last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        customer_financial_details = [
                            pybusinesscentral.model.customer_financial_detail.customerFinancialDetail(
                                id = '', 
                                number = '', 
                                balance = 1.337, 
                                total_sales_excluding_tax = 1.337, 
                                overdue_amount = 1.337, )
                            ], 
                        picture = [
                            pybusinesscentral.model.picture.picture(
                                id = '', 
                                width = 56, 
                                height = 56, 
                                content_type = '', 
                                content@odata/media_edit_link = '', 
                                content@odata/media_read_link = '', )
                            ], 
                        default_dimensions = [
                            pybusinesscentral.model.default_dimensions.defaultDimensions(
                                parent_id = '', 
                                dimension_id = '', 
                                dimension_code = '', 
                                dimension_value_id = '', 
                                dimension_value_code = '', 
                                posting_validation = '', 
                                account = pybusinesscentral.model.account.account(
                                    id = '', 
                                    number = '', 
                                    display_name = '', 
                                    category = '', 
                                    sub_category = '', 
                                    blocked = True, 
                                    last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), 
                                dimension = pybusinesscentral.model.dimension.dimension(
                                    id = '', 
                                    code = '', 
                                    display_name = '', 
                                    last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                    dimension_values = [
                                        pybusinesscentral.model.dimension_value.dimensionValue(
                                            id = '', 
                                            code = '', 
                                            display_name = '', 
                                            last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                                        ], ), 
                                dimension_value = pybusinesscentral.model.dimension_value.dimensionValue(
                                    id = '', 
                                    code = '', 
                                    display_name = '', 
                                    last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), )
                            ], 
                        currency = pybusinesscentral.model.currency.currency(
                            id = '', 
                            code = '', 
                            display_name = '', 
                            symbol = '', 
                            amount_decimal_places = '', 
                            amount_rounding_precision = 1.337, 
                            last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), 
                        payment_term = pybusinesscentral.model.payment_term.paymentTerm(
                            id = '', 
                            code = '', 
                            display_name = '', 
                            due_date_calculation = '', 
                            discount_date_calculation = '', 
                            discount_percent = 1.337, 
                            calculate_discount_on_credit_memos = True, 
                            last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), 
                        shipment_method = pybusinesscentral.model.shipment_method.shipmentMethod(
                            id = '', 
                            code = '', 
                            display_name = '', 
                            last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), 
                        payment_method = pybusinesscentral.model.payment_method.paymentMethod(
                            id = '', 
                            code = '', 
                            display_name = '', 
                            last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), )
                    ],
                customer_financial_details = [
                    pybusinesscentral.model.customer_financial_detail.customerFinancialDetail(
                        id = '', 
                        number = '', 
                        balance = 1.337, 
                        total_sales_excluding_tax = 1.337, 
                        overdue_amount = 1.337, )
                    ],
                vendors = [
                    pybusinesscentral.model.vendor.vendor(
                        id = '', 
                        number = '', 
                        display_name = '', 
                        address_line1 = '', 
                        address_line2 = '', 
                        city = '', 
                        state = '', 
                        country = '', 
                        postal_code = '', 
                        phone_number = '', 
                        email = '', 
                        website = '', 
                        tax_registration_number = '', 
                        currency_id = '', 
                        currency_code = '', 
                        irs1099_code = '', 
                        payment_terms_id = '', 
                        payment_method_id = '', 
                        tax_liable = True, 
                        blocked = '', 
                        balance = 1.337, 
                        last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        picture = [
                            pybusinesscentral.model.picture.picture(
                                id = '', 
                                width = 56, 
                                height = 56, 
                                content_type = '', 
                                content@odata/media_edit_link = '', 
                                content@odata/media_read_link = '', )
                            ], 
                        default_dimensions = [
                            pybusinesscentral.model.default_dimensions.defaultDimensions(
                                parent_id = '', 
                                dimension_id = '', 
                                dimension_code = '', 
                                dimension_value_id = '', 
                                dimension_value_code = '', 
                                posting_validation = '', 
                                account = pybusinesscentral.model.account.account(
                                    id = '', 
                                    number = '', 
                                    display_name = '', 
                                    category = '', 
                                    sub_category = '', 
                                    blocked = True, 
                                    last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), 
                                dimension = pybusinesscentral.model.dimension.dimension(
                                    id = '', 
                                    code = '', 
                                    display_name = '', 
                                    last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                    dimension_values = [
                                        pybusinesscentral.model.dimension_value.dimensionValue(
                                            id = '', 
                                            code = '', 
                                            display_name = '', 
                                            last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                                        ], ), 
                                dimension_value = pybusinesscentral.model.dimension_value.dimensionValue(
                                    id = '', 
                                    code = '', 
                                    display_name = '', 
                                    last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), )
                            ], 
                        currency = pybusinesscentral.model.currency.currency(
                            id = '', 
                            code = '', 
                            display_name = '', 
                            symbol = '', 
                            amount_decimal_places = '', 
                            amount_rounding_precision = 1.337, 
                            last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), 
                        payment_term = pybusinesscentral.model.payment_term.paymentTerm(
                            id = '', 
                            code = '', 
                            display_name = '', 
                            due_date_calculation = '', 
                            discount_date_calculation = '', 
                            discount_percent = 1.337, 
                            calculate_discount_on_credit_memos = True, 
                            last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), 
                        payment_method = pybusinesscentral.model.payment_method.paymentMethod(
                            id = '', 
                            code = '', 
                            display_name = '', 
                            last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), )
                    ],
                company_information = [
                    pybusinesscentral.model.company_information.companyInformation(
                        id = '', 
                        display_name = '', 
                        address = pybusinesscentral.model.postaladdresstype.postaladdresstype(
                            street = '', 
                            city = '', 
                            state = '', 
                            country_letter_code = '', 
                            postal_code = '', 
                            customer_financial_details = [
                                pybusinesscentral.model.customer_financial_detail.customerFinancialDetail(
                                    id = '', 
                                    number = '', 
                                    balance = 1.337, 
                                    total_sales_excluding_tax = 1.337, 
                                    overdue_amount = 1.337, )
                                ], 
                            picture = [
                                pybusinesscentral.model.picture.picture(
                                    id = '', 
                                    width = 56, 
                                    height = 56, 
                                    content_type = '', 
                                    content@odata/media_edit_link = '', 
                                    content@odata/media_read_link = '', )
                                ], 
                            default_dimensions = [
                                pybusinesscentral.model.default_dimensions.defaultDimensions(
                                    parent_id = '', 
                                    dimension_id = '', 
                                    dimension_code = '', 
                                    dimension_value_id = '', 
                                    dimension_value_code = '', 
                                    posting_validation = '', 
                                    account = pybusinesscentral.model.account.account(
                                        id = '', 
                                        number = '', 
                                        display_name = '', 
                                        category = '', 
                                        sub_category = '', 
                                        blocked = True, 
                                        last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), 
                                    dimension = pybusinesscentral.model.dimension.dimension(
                                        id = '', 
                                        code = '', 
                                        display_name = '', 
                                        last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                        dimension_values = [
                                            pybusinesscentral.model.dimension_value.dimensionValue(
                                                id = '', 
                                                code = '', 
                                                display_name = '', 
                                                last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                                            ], ), 
                                    dimension_value = pybusinesscentral.model.dimension_value.dimensionValue(
                                        id = '', 
                                        code = '', 
                                        display_name = '', 
                                        last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), )
                                ], 
                            currency = pybusinesscentral.model.currency.currency(
                                id = '', 
                                code = '', 
                                display_name = '', 
                                symbol = '', 
                                amount_decimal_places = '', 
                                amount_rounding_precision = 1.337, 
                                last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), 
                            payment_term = pybusinesscentral.model.payment_term.paymentTerm(
                                id = '', 
                                code = '', 
                                display_name = '', 
                                due_date_calculation = '', 
                                discount_date_calculation = '', 
                                discount_percent = 1.337, 
                                calculate_discount_on_credit_memos = True, 
                                last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), 
                            shipment_method = pybusinesscentral.model.shipment_method.shipmentMethod(
                                id = '', 
                                code = '', 
                                display_name = '', 
                                last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), 
                            payment_method = pybusinesscentral.model.payment_method.paymentMethod(
                                id = '', 
                                code = '', 
                                display_name = '', 
                                last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), ), 
                        phone_number = '', 
                        fax_number = '', 
                        email = '', 
                        website = '', 
                        tax_registration_number = '', 
                        currency_code = '', 
                        current_fiscal_year_start_date = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        industry = '', 
                        picture = bytes(b'blah'), 
                        last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                    ],
                sales_invoices = [
                    pybusinesscentral.model.sales_invoice.salesInvoice(
                        id = '', 
                        number = '', 
                        external_document_number = '', 
                        invoice_date = datetime.datetime.strptime('1975-12-30', '%Y-%m-%d').date(), 
                        due_date = datetime.datetime.strptime('1975-12-30', '%Y-%m-%d').date(), 
                        customer_purchase_order_reference = '', 
                        customer_id = '', 
                        contact_id = '', 
                        customer_number = '', 
                        customer_name = '', 
                        bill_to_name = '', 
                        bill_to_customer_id = '', 
                        bill_to_customer_number = '', 
                        ship_to_name = '', 
                        ship_to_contact = '', 
                        selling_postal_address = pybusinesscentral.model.postaladdresstype.postaladdresstype(
                            street = '', 
                            city = '', 
                            state = '', 
                            country_letter_code = '', 
                            postal_code = '', 
                            customer_financial_details = [
                                pybusinesscentral.model.customer_financial_detail.customerFinancialDetail(
                                    id = '', 
                                    number = '', 
                                    balance = 1.337, 
                                    total_sales_excluding_tax = 1.337, 
                                    overdue_amount = 1.337, )
                                ], 
                            picture = [
                                pybusinesscentral.model.picture.picture(
                                    id = '', 
                                    width = 56, 
                                    height = 56, 
                                    content_type = '', 
                                    content@odata/media_edit_link = '', 
                                    content@odata/media_read_link = '', )
                                ], 
                            default_dimensions = [
                                pybusinesscentral.model.default_dimensions.defaultDimensions(
                                    parent_id = '', 
                                    dimension_id = '', 
                                    dimension_code = '', 
                                    dimension_value_id = '', 
                                    dimension_value_code = '', 
                                    posting_validation = '', 
                                    account = pybusinesscentral.model.account.account(
                                        id = '', 
                                        number = '', 
                                        display_name = '', 
                                        category = '', 
                                        sub_category = '', 
                                        blocked = True, 
                                        last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), 
                                    dimension = pybusinesscentral.model.dimension.dimension(
                                        id = '', 
                                        code = '', 
                                        display_name = '', 
                                        last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                        dimension_values = [
                                            pybusinesscentral.model.dimension_value.dimensionValue(
                                                id = '', 
                                                code = '', 
                                                display_name = '', 
                                                last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                                            ], ), 
                                    dimension_value = pybusinesscentral.model.dimension_value.dimensionValue(
                                        id = '', 
                                        code = '', 
                                        display_name = '', 
                                        last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), )
                                ], 
                            currency = pybusinesscentral.model.currency.currency(
                                id = '', 
                                code = '', 
                                display_name = '', 
                                symbol = '', 
                                amount_decimal_places = '', 
                                amount_rounding_precision = 1.337, 
                                last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), 
                            payment_term = pybusinesscentral.model.payment_term.paymentTerm(
                                id = '', 
                                code = '', 
                                display_name = '', 
                                due_date_calculation = '', 
                                discount_date_calculation = '', 
                                discount_percent = 1.337, 
                                calculate_discount_on_credit_memos = True, 
                                last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), 
                            shipment_method = pybusinesscentral.model.shipment_method.shipmentMethod(
                                id = '', 
                                code = '', 
                                display_name = '', 
                                last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), 
                            payment_method = pybusinesscentral.model.payment_method.paymentMethod(
                                id = '', 
                                code = '', 
                                display_name = '', 
                                last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), ), 
                        billing_postal_address = pybusinesscentral.model.postaladdresstype.postaladdresstype(
                            street = '', 
                            city = '', 
                            state = '', 
                            country_letter_code = '', 
                            postal_code = '', ), 
                        shipping_postal_address = , 
                        currency_id = '', 
                        currency_code = '', 
                        order_id = '', 
                        order_number = '', 
                        payment_terms_id = '', 
                        shipment_method_id = '', 
                        salesperson = '', 
                        prices_include_tax = True, 
                        remaining_amount = 1.337, 
                        discount_amount = 1.337, 
                        discount_applied_before_tax = True, 
                        total_amount_excluding_tax = 1.337, 
                        total_tax_amount = 1.337, 
                        total_amount_including_tax = 1.337, 
                        status = '', 
                        last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        phone_number = '', 
                        email = '', 
                        sales_invoice_lines = [
                            pybusinesscentral.model.sales_invoice_line.salesInvoiceLine(
                                id = '', 
                                document_id = '', 
                                sequence = 56, 
                                item_id = '', 
                                account_id = '', 
                                line_type = '', 
                                line_details = pybusinesscentral.model.documentlineobjectdetailstype.documentlineobjectdetailstype(
                                    number = '', 
                                    display_name = '', 
                                    item = pybusinesscentral.model.item.item(
                                        id = '', 
                                        number = '', 
                                        display_name = '', 
                                        type = '', 
                                        item_category_id = '', 
                                        item_category_code = '', 
                                        blocked = True, 
                                        base_unit_of_measure_id = '', 
                                        base_unit_of_measure = pybusinesscentral.model.unitofmeasuretype.unitofmeasuretype(
                                            code = '', 
                                            display_name = '', 
                                            symbol = '', 
                                            unit_conversion = pybusinesscentral.model.itemunitofmeasureconversiontype.itemunitofmeasureconversiontype(
                                                to_unit_of_measure = '', 
                                                from_to_conversion_rate = 1.337, 
                                                item_category = pybusinesscentral.model.item_category.itemCategory(
                                                    id = '', 
                                                    code = '', 
                                                    display_name = '', 
                                                    last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), ), 
                                            item_category = pybusinesscentral.model.item_category.itemCategory(
                                                id = '', 
                                                code = '', 
                                                display_name = '', 
                                                last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), ), 
                                        gtin = '', 
                                        inventory = 1.337, 
                                        unit_price = 1.337, 
                                        price_includes_tax = True, 
                                        unit_cost = 1.337, 
                                        tax_group_id = '', 
                                        tax_group_code = '', 
                                        last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                        item_category = , ), ), 
                                description = '', 
                                unit_of_measure_id = '', 
                                unit_of_measure = pybusinesscentral.model.unitofmeasuretype.unitofmeasuretype(
                                    code = '', 
                                    display_name = '', 
                                    symbol = '', ), 
                                unit_price = 1.337, 
                                quantity = 1.337, 
                                discount_amount = 1.337, 
                                discount_percent = 1.337, 
                                discount_applied_before_tax = True, 
                                amount_excluding_tax = 1.337, 
                                tax_code = '', 
                                tax_percent = 1.337, 
                                total_tax_amount = 1.337, 
                                amount_including_tax = 1.337, 
                                invoice_discount_allocation = 1.337, 
                                net_amount = 1.337, 
                                net_tax_amount = 1.337, 
                                net_amount_including_tax = 1.337, 
                                shipment_date = datetime.datetime.strptime('1975-12-30', '%Y-%m-%d').date(), 
                                item = pybusinesscentral.model.item.item(
                                    id = '', 
                                    number = '', 
                                    display_name = '', 
                                    type = '', 
                                    item_category_id = '', 
                                    item_category_code = '', 
                                    blocked = True, 
                                    base_unit_of_measure_id = '', 
                                    gtin = '', 
                                    inventory = 1.337, 
                                    unit_price = 1.337, 
                                    price_includes_tax = True, 
                                    unit_cost = 1.337, 
                                    tax_group_id = '', 
                                    tax_group_code = '', 
                                    last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), )
                            ], 
                        pdf_document = [
                            pybusinesscentral.model.pdf_document.pdfDocument(
                                id = '', 
                                content = bytes(b'blah'), )
                            ], 
                        customer = pybusinesscentral.model.customer.customer(
                            id = '', 
                            number = '', 
                            display_name = '', 
                            type = '', 
                            address_line1 = '', 
                            address_line2 = '', 
                            city = '', 
                            state = '', 
                            country = '', 
                            postal_code = '', 
                            phone_number = '', 
                            email = '', 
                            website = '', 
                            tax_liable = True, 
                            tax_area_id = '', 
                            tax_area_display_name = '', 
                            tax_registration_number = '', 
                            currency_id = '', 
                            currency_code = '', 
                            payment_terms_id = '', 
                            shipment_method_id = '', 
                            payment_method_id = '', 
                            blocked = '', 
                            last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), 
                        currency = pybusinesscentral.model.currency.currency(
                            id = '', 
                            code = '', 
                            display_name = '', 
                            symbol = '', 
                            amount_decimal_places = '', 
                            amount_rounding_precision = 1.337, 
                            last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), 
                        payment_term = pybusinesscentral.model.payment_term.paymentTerm(
                            id = '', 
                            code = '', 
                            display_name = '', 
                            due_date_calculation = '', 
                            discount_date_calculation = '', 
                            discount_percent = 1.337, 
                            calculate_discount_on_credit_memos = True, 
                            last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), 
                        shipment_method = pybusinesscentral.model.shipment_method.shipmentMethod(
                            id = '', 
                            code = '', 
                            display_name = '', 
                            last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), )
                    ],
                sales_invoice_lines = [
                    pybusinesscentral.model.sales_invoice_line.salesInvoiceLine(
                        id = '', 
                        document_id = '', 
                        sequence = 56, 
                        item_id = '', 
                        account_id = '', 
                        line_type = '', 
                        line_details = pybusinesscentral.model.documentlineobjectdetailstype.documentlineobjectdetailstype(
                            number = '', 
                            display_name = '', 
                            item = pybusinesscentral.model.item.item(
                                id = '', 
                                number = '', 
                                display_name = '', 
                                type = '', 
                                item_category_id = '', 
                                item_category_code = '', 
                                blocked = True, 
                                base_unit_of_measure_id = '', 
                                base_unit_of_measure = pybusinesscentral.model.unitofmeasuretype.unitofmeasuretype(
                                    code = '', 
                                    display_name = '', 
                                    symbol = '', 
                                    unit_conversion = pybusinesscentral.model.itemunitofmeasureconversiontype.itemunitofmeasureconversiontype(
                                        to_unit_of_measure = '', 
                                        from_to_conversion_rate = 1.337, 
                                        picture = [
                                            pybusinesscentral.model.picture.picture(
                                                id = '', 
                                                width = 56, 
                                                height = 56, 
                                                content_type = '', 
                                                content@odata/media_edit_link = '', 
                                                content@odata/media_read_link = '', )
                                            ], 
                                        default_dimensions = [
                                            pybusinesscentral.model.default_dimensions.defaultDimensions(
                                                parent_id = '', 
                                                dimension_id = '', 
                                                dimension_code = '', 
                                                dimension_value_id = '', 
                                                dimension_value_code = '', 
                                                posting_validation = '', 
                                                account = pybusinesscentral.model.account.account(
                                                    id = '', 
                                                    number = '', 
                                                    display_name = '', 
                                                    category = '', 
                                                    sub_category = '', 
                                                    blocked = True, 
                                                    last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), 
                                                dimension = pybusinesscentral.model.dimension.dimension(
                                                    id = '', 
                                                    code = '', 
                                                    display_name = '', 
                                                    last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                    dimension_values = [
                                                        pybusinesscentral.model.dimension_value.dimensionValue(
                                                            id = '', 
                                                            code = '', 
                                                            display_name = '', 
                                                            last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                                                        ], ), 
                                                dimension_value = pybusinesscentral.model.dimension_value.dimensionValue(
                                                    id = '', 
                                                    code = '', 
                                                    display_name = '', 
                                                    last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), )
                                            ], 
                                        item_category = pybusinesscentral.model.item_category.itemCategory(
                                            id = '', 
                                            code = '', 
                                            display_name = '', 
                                            last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), ), 
                                    picture = [
                                        pybusinesscentral.model.picture.picture(
                                            id = '', 
                                            width = 56, 
                                            height = 56, 
                                            content_type = '', 
                                            content@odata/media_edit_link = '', 
                                            content@odata/media_read_link = '', )
                                        ], 
                                    default_dimensions = [
                                        pybusinesscentral.model.default_dimensions.defaultDimensions(
                                            parent_id = '', 
                                            dimension_id = '', 
                                            dimension_code = '', 
                                            dimension_value_id = '', 
                                            dimension_value_code = '', 
                                            posting_validation = '', )
                                        ], 
                                    item_category = pybusinesscentral.model.item_category.itemCategory(
                                        id = '', 
                                        code = '', 
                                        display_name = '', 
                                        last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), ), 
                                gtin = '', 
                                inventory = 1.337, 
                                unit_price = 1.337, 
                                price_includes_tax = True, 
                                unit_cost = 1.337, 
                                tax_group_id = '', 
                                tax_group_code = '', 
                                last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                picture = , 
                                default_dimensions = , 
                                item_category = , ), 
                            account = pybusinesscentral.model.account.account(
                                id = '', 
                                number = '', 
                                display_name = '', 
                                category = '', 
                                sub_category = '', 
                                blocked = True, 
                                last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), ), 
                        description = '', 
                        unit_of_measure_id = '', 
                        unit_of_measure = pybusinesscentral.model.unitofmeasuretype.unitofmeasuretype(
                            code = '', 
                            display_name = '', 
                            symbol = '', ), 
                        unit_price = 1.337, 
                        quantity = 1.337, 
                        discount_amount = 1.337, 
                        discount_percent = 1.337, 
                        discount_applied_before_tax = True, 
                        amount_excluding_tax = 1.337, 
                        tax_code = '', 
                        tax_percent = 1.337, 
                        total_tax_amount = 1.337, 
                        amount_including_tax = 1.337, 
                        invoice_discount_allocation = 1.337, 
                        net_amount = 1.337, 
                        net_tax_amount = 1.337, 
                        net_amount_including_tax = 1.337, 
                        shipment_date = datetime.datetime.strptime('1975-12-30', '%Y-%m-%d').date(), 
                        item = pybusinesscentral.model.item.item(
                            id = '', 
                            number = '', 
                            display_name = '', 
                            type = '', 
                            item_category_id = '', 
                            item_category_code = '', 
                            blocked = True, 
                            base_unit_of_measure_id = '', 
                            gtin = '', 
                            inventory = 1.337, 
                            unit_price = 1.337, 
                            price_includes_tax = True, 
                            unit_cost = 1.337, 
                            tax_group_id = '', 
                            tax_group_code = '', 
                            last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), 
                        account = , )
                    ],
                pdf_document = [
                    pybusinesscentral.model.pdf_document.pdfDocument(
                        id = '', 
                        content = bytes(b'blah'), )
                    ],
                customer_payment_journals = [
                    pybusinesscentral.model.customer_payment_journal.customerPaymentJournal(
                        id = '', 
                        code = '', 
                        display_name = '', 
                        last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        balancing_account_id = '', 
                        balancing_account_number = '', 
                        customer_payments = [
                            pybusinesscentral.model.customer_payment.customerPayment(
                                id = '', 
                                journal_display_name = '', 
                                line_number = 56, 
                                customer_id = '', 
                                customer_number = '', 
                                contact_id = '', 
                                posting_date = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                document_number = '', 
                                external_document_number = '', 
                                amount = 1.337, 
                                applies_to_invoice_id = '', 
                                applies_to_invoice_number = '', 
                                description = '', 
                                comment = '', 
                                dimensions = [
                                    null
                                    ], 
                                last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                customer = pybusinesscentral.model.customer.customer(
                                    id = '', 
                                    number = '', 
                                    display_name = '', 
                                    type = '', 
                                    address_line1 = '', 
                                    address_line2 = '', 
                                    city = '', 
                                    state = '', 
                                    country = '', 
                                    postal_code = '', 
                                    phone_number = '', 
                                    email = '', 
                                    website = '', 
                                    tax_liable = True, 
                                    tax_area_id = '', 
                                    tax_area_display_name = '', 
                                    tax_registration_number = '', 
                                    currency_id = '', 
                                    currency_code = '', 
                                    payment_terms_id = '', 
                                    shipment_method_id = '', 
                                    payment_method_id = '', 
                                    blocked = '', 
                                    last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                    customer_financial_details = [
                                        pybusinesscentral.model.customer_financial_detail.customerFinancialDetail(
                                            id = '', 
                                            number = '', 
                                            balance = 1.337, 
                                            total_sales_excluding_tax = 1.337, 
                                            overdue_amount = 1.337, )
                                        ], 
                                    picture = [
                                        pybusinesscentral.model.picture.picture(
                                            id = '', 
                                            width = 56, 
                                            height = 56, 
                                            content_type = '', 
                                            content@odata/media_edit_link = '', 
                                            content@odata/media_read_link = '', )
                                        ], 
                                    default_dimensions = [
                                        pybusinesscentral.model.default_dimensions.defaultDimensions(
                                            parent_id = '', 
                                            dimension_id = '', 
                                            dimension_code = '', 
                                            dimension_value_id = '', 
                                            dimension_value_code = '', 
                                            posting_validation = '', 
                                            account = pybusinesscentral.model.account.account(
                                                id = '', 
                                                number = '', 
                                                display_name = '', 
                                                category = '', 
                                                sub_category = '', 
                                                blocked = True, 
                                                last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), 
                                            dimension = pybusinesscentral.model.dimension.dimension(
                                                id = '', 
                                                code = '', 
                                                display_name = '', 
                                                last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                dimension_values = [
                                                    pybusinesscentral.model.dimension_value.dimensionValue(
                                                        id = '', 
                                                        code = '', 
                                                        display_name = '', 
                                                        last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                                                    ], ), 
                                            dimension_value = pybusinesscentral.model.dimension_value.dimensionValue(
                                                id = '', 
                                                code = '', 
                                                display_name = '', 
                                                last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), )
                                        ], 
                                    currency = pybusinesscentral.model.currency.currency(
                                        id = '', 
                                        code = '', 
                                        display_name = '', 
                                        symbol = '', 
                                        amount_decimal_places = '', 
                                        amount_rounding_precision = 1.337, 
                                        last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), 
                                    payment_term = pybusinesscentral.model.payment_term.paymentTerm(
                                        id = '', 
                                        code = '', 
                                        display_name = '', 
                                        due_date_calculation = '', 
                                        discount_date_calculation = '', 
                                        discount_percent = 1.337, 
                                        calculate_discount_on_credit_memos = True, 
                                        last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), 
                                    shipment_method = pybusinesscentral.model.shipment_method.shipmentMethod(
                                        id = '', 
                                        code = '', 
                                        display_name = '', 
                                        last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), 
                                    payment_method = pybusinesscentral.model.payment_method.paymentMethod(
                                        id = '', 
                                        code = '', 
                                        display_name = '', 
                                        last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), ), )
                            ], 
                        account = pybusinesscentral.model.account.account(
                            id = '', 
                            number = '', 
                            display_name = '', 
                            category = '', 
                            sub_category = '', 
                            blocked = True, 
                            last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), )
                    ],
                customer_payments = [
                    pybusinesscentral.model.customer_payment.customerPayment(
                        id = '', 
                        journal_display_name = '', 
                        line_number = 56, 
                        customer_id = '', 
                        customer_number = '', 
                        contact_id = '', 
                        posting_date = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        document_number = '', 
                        external_document_number = '', 
                        amount = 1.337, 
                        applies_to_invoice_id = '', 
                        applies_to_invoice_number = '', 
                        description = '', 
                        comment = '', 
                        dimensions = [
                            null
                            ], 
                        last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        customer = pybusinesscentral.model.customer.customer(
                            id = '', 
                            number = '', 
                            display_name = '', 
                            type = '', 
                            address_line1 = '', 
                            address_line2 = '', 
                            city = '', 
                            state = '', 
                            country = '', 
                            postal_code = '', 
                            phone_number = '', 
                            email = '', 
                            website = '', 
                            tax_liable = True, 
                            tax_area_id = '', 
                            tax_area_display_name = '', 
                            tax_registration_number = '', 
                            currency_id = '', 
                            currency_code = '', 
                            payment_terms_id = '', 
                            shipment_method_id = '', 
                            payment_method_id = '', 
                            blocked = '', 
                            last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            customer_financial_details = [
                                pybusinesscentral.model.customer_financial_detail.customerFinancialDetail(
                                    id = '', 
                                    number = '', 
                                    balance = 1.337, 
                                    total_sales_excluding_tax = 1.337, 
                                    overdue_amount = 1.337, )
                                ], 
                            picture = [
                                pybusinesscentral.model.picture.picture(
                                    id = '', 
                                    width = 56, 
                                    height = 56, 
                                    content_type = '', 
                                    content@odata/media_edit_link = '', 
                                    content@odata/media_read_link = '', )
                                ], 
                            default_dimensions = [
                                pybusinesscentral.model.default_dimensions.defaultDimensions(
                                    parent_id = '', 
                                    dimension_id = '', 
                                    dimension_code = '', 
                                    dimension_value_id = '', 
                                    dimension_value_code = '', 
                                    posting_validation = '', 
                                    account = pybusinesscentral.model.account.account(
                                        id = '', 
                                        number = '', 
                                        display_name = '', 
                                        category = '', 
                                        sub_category = '', 
                                        blocked = True, 
                                        last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), 
                                    dimension = pybusinesscentral.model.dimension.dimension(
                                        id = '', 
                                        code = '', 
                                        display_name = '', 
                                        last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                        dimension_values = [
                                            pybusinesscentral.model.dimension_value.dimensionValue(
                                                id = '', 
                                                code = '', 
                                                display_name = '', 
                                                last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                                            ], ), 
                                    dimension_value = pybusinesscentral.model.dimension_value.dimensionValue(
                                        id = '', 
                                        code = '', 
                                        display_name = '', 
                                        last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), )
                                ], 
                            currency = pybusinesscentral.model.currency.currency(
                                id = '', 
                                code = '', 
                                display_name = '', 
                                symbol = '', 
                                amount_decimal_places = '', 
                                amount_rounding_precision = 1.337, 
                                last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), 
                            payment_term = pybusinesscentral.model.payment_term.paymentTerm(
                                id = '', 
                                code = '', 
                                display_name = '', 
                                due_date_calculation = '', 
                                discount_date_calculation = '', 
                                discount_percent = 1.337, 
                                calculate_discount_on_credit_memos = True, 
                                last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), 
                            shipment_method = pybusinesscentral.model.shipment_method.shipmentMethod(
                                id = '', 
                                code = '', 
                                display_name = '', 
                                last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), 
                            payment_method = pybusinesscentral.model.payment_method.paymentMethod(
                                id = '', 
                                code = '', 
                                display_name = '', 
                                last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), ), )
                    ],
                accounts = [
                    pybusinesscentral.model.account.account(
                        id = '', 
                        number = '', 
                        display_name = '', 
                        category = '', 
                        sub_category = '', 
                        blocked = True, 
                        last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                    ],
                tax_groups = [
                    pybusinesscentral.model.tax_group.taxGroup(
                        id = '', 
                        code = '', 
                        display_name = '', 
                        tax_type = '', 
                        last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                    ],
                journals = [
                    pybusinesscentral.model.journal.journal(
                        id = '', 
                        code = '', 
                        display_name = '', 
                        last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        balancing_account_id = '', 
                        balancing_account_number = '', 
                        journal_lines = [
                            pybusinesscentral.model.journal_line.journalLine(
                                id = '', 
                                journal_display_name = '', 
                                line_number = 56, 
                                account_type = '', 
                                account_id = '', 
                                account_number = '', 
                                posting_date = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                document_number = '', 
                                external_document_number = '', 
                                amount = 1.337, 
                                description = '', 
                                comment = '', 
                                dimensions = [
                                    null
                                    ], 
                                last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                attachments = [
                                    pybusinesscentral.model.attachments.attachments(
                                        parent_id = '', 
                                        id = '', 
                                        file_name = '', 
                                        byte_size = 56, 
                                        content = bytes(b'blah'), 
                                        last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                                    ], 
                                account = pybusinesscentral.model.account.account(
                                    id = '', 
                                    number = '', 
                                    display_name = '', 
                                    category = '', 
                                    sub_category = '', 
                                    blocked = True, 
                                    last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), )
                            ], 
                        account = pybusinesscentral.model.account.account(
                            id = '', 
                            number = '', 
                            display_name = '', 
                            category = '', 
                            sub_category = '', 
                            blocked = True, 
                            last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), )
                    ],
                journal_lines = [
                    pybusinesscentral.model.journal_line.journalLine(
                        id = '', 
                        journal_display_name = '', 
                        line_number = 56, 
                        account_type = '', 
                        account_id = '', 
                        account_number = '', 
                        posting_date = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        document_number = '', 
                        external_document_number = '', 
                        amount = 1.337, 
                        description = '', 
                        comment = '', 
                        dimensions = [
                            null
                            ], 
                        last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        attachments = [
                            pybusinesscentral.model.attachments.attachments(
                                parent_id = '', 
                                id = '', 
                                file_name = '', 
                                byte_size = 56, 
                                content = bytes(b'blah'), 
                                last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                            ], 
                        account = pybusinesscentral.model.account.account(
                            id = '', 
                            number = '', 
                            display_name = '', 
                            category = '', 
                            sub_category = '', 
                            blocked = True, 
                            last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), )
                    ],
                attachments = [
                    pybusinesscentral.model.attachments.attachments(
                        parent_id = '', 
                        id = '', 
                        file_name = '', 
                        byte_size = 56, 
                        content = bytes(b'blah'), 
                        last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                    ],
                employees = [
                    pybusinesscentral.model.employee.employee(
                        id = '', 
                        number = '', 
                        display_name = '', 
                        given_name = '', 
                        middle_name = '', 
                        surname = '', 
                        job_title = '', 
                        address = pybusinesscentral.model.postaladdresstype.postaladdresstype(
                            street = '', 
                            city = '', 
                            state = '', 
                            country_letter_code = '', 
                            postal_code = '', 
                            customer_financial_details = [
                                pybusinesscentral.model.customer_financial_detail.customerFinancialDetail(
                                    id = '', 
                                    number = '', 
                                    balance = 1.337, 
                                    total_sales_excluding_tax = 1.337, 
                                    overdue_amount = 1.337, )
                                ], 
                            picture = [
                                pybusinesscentral.model.picture.picture(
                                    id = '', 
                                    width = 56, 
                                    height = 56, 
                                    content_type = '', 
                                    content@odata/media_edit_link = '', 
                                    content@odata/media_read_link = '', )
                                ], 
                            default_dimensions = [
                                pybusinesscentral.model.default_dimensions.defaultDimensions(
                                    parent_id = '', 
                                    dimension_id = '', 
                                    dimension_code = '', 
                                    dimension_value_id = '', 
                                    dimension_value_code = '', 
                                    posting_validation = '', 
                                    account = pybusinesscentral.model.account.account(
                                        id = '', 
                                        number = '', 
                                        display_name = '', 
                                        category = '', 
                                        sub_category = '', 
                                        blocked = True, 
                                        last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), 
                                    dimension = pybusinesscentral.model.dimension.dimension(
                                        id = '', 
                                        code = '', 
                                        display_name = '', 
                                        last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                        dimension_values = [
                                            pybusinesscentral.model.dimension_value.dimensionValue(
                                                id = '', 
                                                code = '', 
                                                display_name = '', 
                                                last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                                            ], ), 
                                    dimension_value = pybusinesscentral.model.dimension_value.dimensionValue(
                                        id = '', 
                                        code = '', 
                                        display_name = '', 
                                        last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), )
                                ], 
                            currency = pybusinesscentral.model.currency.currency(
                                id = '', 
                                code = '', 
                                display_name = '', 
                                symbol = '', 
                                amount_decimal_places = '', 
                                amount_rounding_precision = 1.337, 
                                last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), 
                            payment_term = pybusinesscentral.model.payment_term.paymentTerm(
                                id = '', 
                                code = '', 
                                display_name = '', 
                                due_date_calculation = '', 
                                discount_date_calculation = '', 
                                discount_percent = 1.337, 
                                calculate_discount_on_credit_memos = True, 
                                last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), 
                            shipment_method = pybusinesscentral.model.shipment_method.shipmentMethod(
                                id = '', 
                                code = '', 
                                display_name = '', 
                                last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), 
                            payment_method = pybusinesscentral.model.payment_method.paymentMethod(
                                id = '', 
                                code = '', 
                                display_name = '', 
                                last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), ), 
                        phone_number = '', 
                        mobile_phone = '', 
                        email = '', 
                        personal_email = '', 
                        employment_date = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        termination_date = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        status = '', 
                        birth_date = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        statistics_group_code = '', 
                        last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        picture = [
                            pybusinesscentral.model.picture.picture(
                                id = '', 
                                width = 56, 
                                height = 56, 
                                content_type = '', 
                                content@odata/media_edit_link = '', 
                                content@odata/media_read_link = '', )
                            ], 
                        default_dimensions = [
                            pybusinesscentral.model.default_dimensions.defaultDimensions(
                                parent_id = '', 
                                dimension_id = '', 
                                dimension_code = '', 
                                dimension_value_id = '', 
                                dimension_value_code = '', 
                                posting_validation = '', )
                            ], 
                        time_registration_entries = [
                            pybusinesscentral.model.time_registration_entry.timeRegistrationEntry(
                                id = '', 
                                employee_id = '', 
                                employee_number = '', 
                                job_id = '', 
                                job_number = '', 
                                absence = '', 
                                line_number = 56, 
                                date = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                quantity = 1.337, 
                                status = '', 
                                unit_of_measure_id = '', 
                                unit_of_measure = pybusinesscentral.model.unitofmeasuretype.unitofmeasuretype(
                                    code = '', 
                                    display_name = '', 
                                    symbol = '', 
                                    unit_conversion = pybusinesscentral.model.itemunitofmeasureconversiontype.itemunitofmeasureconversiontype(
                                        to_unit_of_measure = '', 
                                        from_to_conversion_rate = 1.337, 
                                        item_category = pybusinesscentral.model.item_category.itemCategory(
                                            id = '', 
                                            code = '', 
                                            display_name = '', 
                                            last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), ), 
                                    item_category = pybusinesscentral.model.item_category.itemCategory(
                                        id = '', 
                                        code = '', 
                                        display_name = '', 
                                        last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), ), 
                                dimensions = [
                                    null
                                    ], 
                                last_modfied_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                project = pybusinesscentral.model.project.project(
                                    id = '', 
                                    number = '', 
                                    display_name = '', ), )
                            ], )
                    ],
                time_registration_entries = [
                    pybusinesscentral.model.time_registration_entry.timeRegistrationEntry(
                        id = '', 
                        employee_id = '', 
                        employee_number = '', 
                        job_id = '', 
                        job_number = '', 
                        absence = '', 
                        line_number = 56, 
                        date = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        quantity = 1.337, 
                        status = '', 
                        unit_of_measure_id = '', 
                        unit_of_measure = pybusinesscentral.model.unitofmeasuretype.unitofmeasuretype(
                            code = '', 
                            display_name = '', 
                            symbol = '', 
                            unit_conversion = pybusinesscentral.model.itemunitofmeasureconversiontype.itemunitofmeasureconversiontype(
                                to_unit_of_measure = '', 
                                from_to_conversion_rate = 1.337, 
                                picture = [
                                    pybusinesscentral.model.picture.picture(
                                        id = '', 
                                        width = 56, 
                                        height = 56, 
                                        content_type = '', 
                                        content@odata/media_edit_link = '', 
                                        content@odata/media_read_link = '', )
                                    ], 
                                default_dimensions = [
                                    pybusinesscentral.model.default_dimensions.defaultDimensions(
                                        parent_id = '', 
                                        dimension_id = '', 
                                        dimension_code = '', 
                                        dimension_value_id = '', 
                                        dimension_value_code = '', 
                                        posting_validation = '', 
                                        account = pybusinesscentral.model.account.account(
                                            id = '', 
                                            number = '', 
                                            display_name = '', 
                                            category = '', 
                                            sub_category = '', 
                                            blocked = True, 
                                            last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), 
                                        dimension = pybusinesscentral.model.dimension.dimension(
                                            id = '', 
                                            code = '', 
                                            display_name = '', 
                                            last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                            dimension_values = [
                                                pybusinesscentral.model.dimension_value.dimensionValue(
                                                    id = '', 
                                                    code = '', 
                                                    display_name = '', 
                                                    last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                                                ], ), 
                                        dimension_value = pybusinesscentral.model.dimension_value.dimensionValue(
                                            id = '', 
                                            code = '', 
                                            display_name = '', 
                                            last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), )
                                    ], 
                                item_category = pybusinesscentral.model.item_category.itemCategory(
                                    id = '', 
                                    code = '', 
                                    display_name = '', 
                                    last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), ), 
                            picture = [
                                pybusinesscentral.model.picture.picture(
                                    id = '', 
                                    width = 56, 
                                    height = 56, 
                                    content_type = '', 
                                    content@odata/media_edit_link = '', 
                                    content@odata/media_read_link = '', )
                                ], 
                            default_dimensions = [
                                pybusinesscentral.model.default_dimensions.defaultDimensions(
                                    parent_id = '', 
                                    dimension_id = '', 
                                    dimension_code = '', 
                                    dimension_value_id = '', 
                                    dimension_value_code = '', 
                                    posting_validation = '', )
                                ], 
                            item_category = pybusinesscentral.model.item_category.itemCategory(
                                id = '', 
                                code = '', 
                                display_name = '', 
                                last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), ), 
                        dimensions = [
                            null
                            ], 
                        last_modfied_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        project = pybusinesscentral.model.project.project(
                            id = '', 
                            number = '', 
                            display_name = '', ), )
                    ],
                general_ledger_entries = [
                    pybusinesscentral.model.general_ledger_entry.generalLedgerEntry(
                        id = 56, 
                        posting_date = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        document_number = '', 
                        document_type = '', 
                        account_id = '', 
                        account_number = '', 
                        description = '', 
                        debit_amount = 1.337, 
                        credit_amount = 1.337, 
                        dimensions = [
                            null
                            ], 
                        last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        account = pybusinesscentral.model.account.account(
                            id = '', 
                            number = '', 
                            display_name = '', 
                            category = '', 
                            sub_category = '', 
                            blocked = True, 
                            last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), )
                    ],
                currencies = [
                    pybusinesscentral.model.currency.currency(
                        id = '', 
                        code = '', 
                        display_name = '', 
                        symbol = '', 
                        amount_decimal_places = '', 
                        amount_rounding_precision = 1.337, 
                        last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                    ],
                payment_methods = [
                    pybusinesscentral.model.payment_method.paymentMethod(
                        id = '', 
                        code = '', 
                        display_name = '', 
                        last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                    ],
                dimensions = [
                    pybusinesscentral.model.dimension.dimension(
                        id = '', 
                        code = '', 
                        display_name = '', 
                        last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        dimension_values = [
                            pybusinesscentral.model.dimension_value.dimensionValue(
                                id = '', 
                                code = '', 
                                display_name = '', 
                                last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                            ], )
                    ],
                dimension_values = [
                    pybusinesscentral.model.dimension_value.dimensionValue(
                        id = '', 
                        code = '', 
                        display_name = '', 
                        last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                    ],
                dimension_lines = [
                    pybusinesscentral.model.dimension_line.dimensionLine(
                        parent_id = '', 
                        id = '', 
                        code = '', 
                        display_name = '', 
                        value_id = '', 
                        value_code = '', 
                        value_display_name = '', 
                        dimension = pybusinesscentral.model.dimension.dimension(
                            id = '', 
                            code = '', 
                            display_name = '', 
                            last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            dimension_values = [
                                pybusinesscentral.model.dimension_value.dimensionValue(
                                    id = '', 
                                    code = '', 
                                    display_name = '', 
                                    last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                                ], ), )
                    ],
                payment_terms = [
                    pybusinesscentral.model.payment_term.paymentTerm(
                        id = '', 
                        code = '', 
                        display_name = '', 
                        due_date_calculation = '', 
                        discount_date_calculation = '', 
                        discount_percent = 1.337, 
                        calculate_discount_on_credit_memos = True, 
                        last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                    ],
                shipment_methods = [
                    pybusinesscentral.model.shipment_method.shipmentMethod(
                        id = '', 
                        code = '', 
                        display_name = '', 
                        last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                    ],
                item_categories = [
                    pybusinesscentral.model.item_category.itemCategory(
                        id = '', 
                        code = '', 
                        display_name = '', 
                        last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                    ],
                cash_flow_statement = [
                    pybusinesscentral.model.cash_flow_statement.cashFlowStatement(
                        line_number = 56, 
                        display = '', 
                        net_change = 1.337, 
                        line_type = '', 
                        indentation = 56, 
                        date_filter = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                    ],
                countries_regions = [
                    pybusinesscentral.model.country_region.countryRegion(
                        id = '', 
                        code = '', 
                        display_name = '', 
                        address_format = '', 
                        last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                    ],
                sales_orders = [
                    pybusinesscentral.model.sales_order.salesOrder(
                        id = '', 
                        number = '', 
                        external_document_number = '', 
                        order_date = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        customer_id = '', 
                        contact_id = '', 
                        customer_number = '', 
                        customer_name = '', 
                        bill_to_name = '', 
                        bill_to_customer_id = '', 
                        bill_to_customer_number = '', 
                        ship_to_name = '', 
                        ship_to_contact = '', 
                        selling_postal_address = pybusinesscentral.model.postaladdresstype.postaladdresstype(
                            street = '', 
                            city = '', 
                            state = '', 
                            country_letter_code = '', 
                            postal_code = '', 
                            customer_financial_details = [
                                pybusinesscentral.model.customer_financial_detail.customerFinancialDetail(
                                    id = '', 
                                    number = '', 
                                    balance = 1.337, 
                                    total_sales_excluding_tax = 1.337, 
                                    overdue_amount = 1.337, )
                                ], 
                            picture = [
                                pybusinesscentral.model.picture.picture(
                                    id = '', 
                                    width = 56, 
                                    height = 56, 
                                    content_type = '', 
                                    content@odata/media_edit_link = '', 
                                    content@odata/media_read_link = '', )
                                ], 
                            default_dimensions = [
                                pybusinesscentral.model.default_dimensions.defaultDimensions(
                                    parent_id = '', 
                                    dimension_id = '', 
                                    dimension_code = '', 
                                    dimension_value_id = '', 
                                    dimension_value_code = '', 
                                    posting_validation = '', 
                                    account = pybusinesscentral.model.account.account(
                                        id = '', 
                                        number = '', 
                                        display_name = '', 
                                        category = '', 
                                        sub_category = '', 
                                        blocked = True, 
                                        last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), 
                                    dimension = pybusinesscentral.model.dimension.dimension(
                                        id = '', 
                                        code = '', 
                                        display_name = '', 
                                        last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                        dimension_values = [
                                            pybusinesscentral.model.dimension_value.dimensionValue(
                                                id = '', 
                                                code = '', 
                                                display_name = '', 
                                                last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                                            ], ), 
                                    dimension_value = pybusinesscentral.model.dimension_value.dimensionValue(
                                        id = '', 
                                        code = '', 
                                        display_name = '', 
                                        last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), )
                                ], 
                            currency = pybusinesscentral.model.currency.currency(
                                id = '', 
                                code = '', 
                                display_name = '', 
                                symbol = '', 
                                amount_decimal_places = '', 
                                amount_rounding_precision = 1.337, 
                                last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), 
                            payment_term = pybusinesscentral.model.payment_term.paymentTerm(
                                id = '', 
                                code = '', 
                                display_name = '', 
                                due_date_calculation = '', 
                                discount_date_calculation = '', 
                                discount_percent = 1.337, 
                                calculate_discount_on_credit_memos = True, 
                                last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), 
                            shipment_method = pybusinesscentral.model.shipment_method.shipmentMethod(
                                id = '', 
                                code = '', 
                                display_name = '', 
                                last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), 
                            payment_method = pybusinesscentral.model.payment_method.paymentMethod(
                                id = '', 
                                code = '', 
                                display_name = '', 
                                last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), ), 
                        billing_postal_address = pybusinesscentral.model.postaladdresstype.postaladdresstype(
                            street = '', 
                            city = '', 
                            state = '', 
                            country_letter_code = '', 
                            postal_code = '', ), 
                        shipping_postal_address = , 
                        currency_id = '', 
                        currency_code = '', 
                        prices_include_tax = True, 
                        payment_terms_id = '', 
                        shipment_method_id = '', 
                        salesperson = '', 
                        partial_shipping = True, 
                        requested_delivery_date = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        discount_amount = 1.337, 
                        discount_applied_before_tax = True, 
                        total_amount_excluding_tax = 1.337, 
                        total_tax_amount = 1.337, 
                        total_amount_including_tax = 1.337, 
                        fully_shipped = True, 
                        status = '', 
                        last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        phone_number = '', 
                        email = '', 
                        sales_order_lines = [
                            pybusinesscentral.model.sales_order_line.salesOrderLine(
                                id = '', 
                                document_id = '', 
                                sequence = 56, 
                                item_id = '', 
                                account_id = '', 
                                line_type = '', 
                                line_details = pybusinesscentral.model.documentlineobjectdetailstype.documentlineobjectdetailstype(
                                    number = '', 
                                    display_name = '', 
                                    item = pybusinesscentral.model.item.item(
                                        id = '', 
                                        number = '', 
                                        display_name = '', 
                                        type = '', 
                                        item_category_id = '', 
                                        item_category_code = '', 
                                        blocked = True, 
                                        base_unit_of_measure_id = '', 
                                        base_unit_of_measure = pybusinesscentral.model.unitofmeasuretype.unitofmeasuretype(
                                            code = '', 
                                            display_name = '', 
                                            symbol = '', 
                                            unit_conversion = pybusinesscentral.model.itemunitofmeasureconversiontype.itemunitofmeasureconversiontype(
                                                to_unit_of_measure = '', 
                                                from_to_conversion_rate = 1.337, 
                                                item_category = pybusinesscentral.model.item_category.itemCategory(
                                                    id = '', 
                                                    code = '', 
                                                    display_name = '', 
                                                    last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), ), 
                                            item_category = pybusinesscentral.model.item_category.itemCategory(
                                                id = '', 
                                                code = '', 
                                                display_name = '', 
                                                last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), ), 
                                        gtin = '', 
                                        inventory = 1.337, 
                                        unit_price = 1.337, 
                                        price_includes_tax = True, 
                                        unit_cost = 1.337, 
                                        tax_group_id = '', 
                                        tax_group_code = '', 
                                        last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                        item_category = , ), ), 
                                description = '', 
                                unit_of_measure_id = '', 
                                unit_of_measure = pybusinesscentral.model.unitofmeasuretype.unitofmeasuretype(
                                    code = '', 
                                    display_name = '', 
                                    symbol = '', ), 
                                quantity = 1.337, 
                                unit_price = 1.337, 
                                discount_amount = 1.337, 
                                discount_percent = 1.337, 
                                discount_applied_before_tax = True, 
                                amount_excluding_tax = 1.337, 
                                tax_code = '', 
                                tax_percent = 1.337, 
                                total_tax_amount = 1.337, 
                                amount_including_tax = 1.337, 
                                invoice_discount_allocation = 1.337, 
                                net_amount = 1.337, 
                                net_tax_amount = 1.337, 
                                net_amount_including_tax = 1.337, 
                                shipment_date = datetime.datetime.strptime('1975-12-30', '%Y-%m-%d').date(), 
                                shipped_quantity = 1.337, 
                                invoiced_quantity = 1.337, 
                                invoice_quantity = 1.337, 
                                ship_quantity = 1.337, 
                                item = pybusinesscentral.model.item.item(
                                    id = '', 
                                    number = '', 
                                    display_name = '', 
                                    type = '', 
                                    item_category_id = '', 
                                    item_category_code = '', 
                                    blocked = True, 
                                    base_unit_of_measure_id = '', 
                                    gtin = '', 
                                    inventory = 1.337, 
                                    unit_price = 1.337, 
                                    price_includes_tax = True, 
                                    unit_cost = 1.337, 
                                    tax_group_id = '', 
                                    tax_group_code = '', 
                                    last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), )
                            ], 
                        customer = pybusinesscentral.model.customer.customer(
                            id = '', 
                            number = '', 
                            display_name = '', 
                            type = '', 
                            address_line1 = '', 
                            address_line2 = '', 
                            city = '', 
                            state = '', 
                            country = '', 
                            postal_code = '', 
                            phone_number = '', 
                            email = '', 
                            website = '', 
                            tax_liable = True, 
                            tax_area_id = '', 
                            tax_area_display_name = '', 
                            tax_registration_number = '', 
                            currency_id = '', 
                            currency_code = '', 
                            payment_terms_id = '', 
                            shipment_method_id = '', 
                            payment_method_id = '', 
                            blocked = '', 
                            last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), 
                        currency = pybusinesscentral.model.currency.currency(
                            id = '', 
                            code = '', 
                            display_name = '', 
                            symbol = '', 
                            amount_decimal_places = '', 
                            amount_rounding_precision = 1.337, 
                            last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), 
                        payment_term = pybusinesscentral.model.payment_term.paymentTerm(
                            id = '', 
                            code = '', 
                            display_name = '', 
                            due_date_calculation = '', 
                            discount_date_calculation = '', 
                            discount_percent = 1.337, 
                            calculate_discount_on_credit_memos = True, 
                            last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), 
                        shipment_method = pybusinesscentral.model.shipment_method.shipmentMethod(
                            id = '', 
                            code = '', 
                            display_name = '', 
                            last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), )
                    ],
                sales_order_lines = [
                    pybusinesscentral.model.sales_order_line.salesOrderLine(
                        id = '', 
                        document_id = '', 
                        sequence = 56, 
                        item_id = '', 
                        account_id = '', 
                        line_type = '', 
                        line_details = pybusinesscentral.model.documentlineobjectdetailstype.documentlineobjectdetailstype(
                            number = '', 
                            display_name = '', 
                            item = pybusinesscentral.model.item.item(
                                id = '', 
                                number = '', 
                                display_name = '', 
                                type = '', 
                                item_category_id = '', 
                                item_category_code = '', 
                                blocked = True, 
                                base_unit_of_measure_id = '', 
                                base_unit_of_measure = pybusinesscentral.model.unitofmeasuretype.unitofmeasuretype(
                                    code = '', 
                                    display_name = '', 
                                    symbol = '', 
                                    unit_conversion = pybusinesscentral.model.itemunitofmeasureconversiontype.itemunitofmeasureconversiontype(
                                        to_unit_of_measure = '', 
                                        from_to_conversion_rate = 1.337, 
                                        picture = [
                                            pybusinesscentral.model.picture.picture(
                                                id = '', 
                                                width = 56, 
                                                height = 56, 
                                                content_type = '', 
                                                content@odata/media_edit_link = '', 
                                                content@odata/media_read_link = '', )
                                            ], 
                                        default_dimensions = [
                                            pybusinesscentral.model.default_dimensions.defaultDimensions(
                                                parent_id = '', 
                                                dimension_id = '', 
                                                dimension_code = '', 
                                                dimension_value_id = '', 
                                                dimension_value_code = '', 
                                                posting_validation = '', 
                                                account = pybusinesscentral.model.account.account(
                                                    id = '', 
                                                    number = '', 
                                                    display_name = '', 
                                                    category = '', 
                                                    sub_category = '', 
                                                    blocked = True, 
                                                    last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), 
                                                dimension = pybusinesscentral.model.dimension.dimension(
                                                    id = '', 
                                                    code = '', 
                                                    display_name = '', 
                                                    last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                    dimension_values = [
                                                        pybusinesscentral.model.dimension_value.dimensionValue(
                                                            id = '', 
                                                            code = '', 
                                                            display_name = '', 
                                                            last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                                                        ], ), 
                                                dimension_value = pybusinesscentral.model.dimension_value.dimensionValue(
                                                    id = '', 
                                                    code = '', 
                                                    display_name = '', 
                                                    last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), )
                                            ], 
                                        item_category = pybusinesscentral.model.item_category.itemCategory(
                                            id = '', 
                                            code = '', 
                                            display_name = '', 
                                            last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), ), 
                                    picture = [
                                        pybusinesscentral.model.picture.picture(
                                            id = '', 
                                            width = 56, 
                                            height = 56, 
                                            content_type = '', 
                                            content@odata/media_edit_link = '', 
                                            content@odata/media_read_link = '', )
                                        ], 
                                    default_dimensions = [
                                        pybusinesscentral.model.default_dimensions.defaultDimensions(
                                            parent_id = '', 
                                            dimension_id = '', 
                                            dimension_code = '', 
                                            dimension_value_id = '', 
                                            dimension_value_code = '', 
                                            posting_validation = '', )
                                        ], 
                                    item_category = pybusinesscentral.model.item_category.itemCategory(
                                        id = '', 
                                        code = '', 
                                        display_name = '', 
                                        last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), ), 
                                gtin = '', 
                                inventory = 1.337, 
                                unit_price = 1.337, 
                                price_includes_tax = True, 
                                unit_cost = 1.337, 
                                tax_group_id = '', 
                                tax_group_code = '', 
                                last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                picture = , 
                                default_dimensions = , 
                                item_category = , ), 
                            account = pybusinesscentral.model.account.account(
                                id = '', 
                                number = '', 
                                display_name = '', 
                                category = '', 
                                sub_category = '', 
                                blocked = True, 
                                last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), ), 
                        description = '', 
                        unit_of_measure_id = '', 
                        unit_of_measure = pybusinesscentral.model.unitofmeasuretype.unitofmeasuretype(
                            code = '', 
                            display_name = '', 
                            symbol = '', ), 
                        quantity = 1.337, 
                        unit_price = 1.337, 
                        discount_amount = 1.337, 
                        discount_percent = 1.337, 
                        discount_applied_before_tax = True, 
                        amount_excluding_tax = 1.337, 
                        tax_code = '', 
                        tax_percent = 1.337, 
                        total_tax_amount = 1.337, 
                        amount_including_tax = 1.337, 
                        invoice_discount_allocation = 1.337, 
                        net_amount = 1.337, 
                        net_tax_amount = 1.337, 
                        net_amount_including_tax = 1.337, 
                        shipment_date = datetime.datetime.strptime('1975-12-30', '%Y-%m-%d').date(), 
                        shipped_quantity = 1.337, 
                        invoiced_quantity = 1.337, 
                        invoice_quantity = 1.337, 
                        ship_quantity = 1.337, 
                        item = pybusinesscentral.model.item.item(
                            id = '', 
                            number = '', 
                            display_name = '', 
                            type = '', 
                            item_category_id = '', 
                            item_category_code = '', 
                            blocked = True, 
                            base_unit_of_measure_id = '', 
                            gtin = '', 
                            inventory = 1.337, 
                            unit_price = 1.337, 
                            price_includes_tax = True, 
                            unit_cost = 1.337, 
                            tax_group_id = '', 
                            tax_group_code = '', 
                            last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), 
                        account = , )
                    ],
                retained_earnings_statement = [
                    pybusinesscentral.model.retained_earnings_statement.retainedEarningsStatement(
                        line_number = 56, 
                        display = '', 
                        net_change = 1.337, 
                        line_type = '', 
                        indentation = 56, 
                        date_filter = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                    ],
                units_of_measure = [
                    pybusinesscentral.model.unit_of_measure.unitOfMeasure(
                        id = '', 
                        code = '', 
                        display_name = '', 
                        international_standard_code = '', 
                        last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                    ],
                aged_accounts_receivable = [
                    pybusinesscentral.model.aged_accounts_receivable.agedAccountsReceivable(
                        customer_id = '', 
                        customer_number = '', 
                        name = '', 
                        currency_code = '', 
                        balance_due = 1.337, 
                        current_amount = 1.337, 
                        period1_amount = 1.337, 
                        period2_amount = 1.337, 
                        period3_amount = 1.337, 
                        aged_as_of_date = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        period_length_filter = '', )
                    ],
                aged_accounts_payable = [
                    pybusinesscentral.model.aged_accounts_payable.agedAccountsPayable(
                        vendor_id = '', 
                        vendor_number = '', 
                        name = '', 
                        currency_code = '', 
                        balance_due = 1.337, 
                        current_amount = 1.337, 
                        period1_amount = 1.337, 
                        period2_amount = 1.337, 
                        period3_amount = 1.337, 
                        aged_as_of_date = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        period_length_filter = '', )
                    ],
                balance_sheet = [
                    pybusinesscentral.model.balance_sheet.balanceSheet(
                        line_number = 56, 
                        display = '', 
                        balance = 1.337, 
                        line_type = '', 
                        indentation = 56, 
                        date_filter = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                    ],
                trial_balance = [
                    pybusinesscentral.model.trial_balance.trialBalance(
                        number = '', 
                        account_id = '', 
                        account_type = '', 
                        display = '', 
                        total_debit = '', 
                        total_credit = '', 
                        balance_at_date_debit = '', 
                        balance_at_date_credit = '', 
                        date_filter = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        account = pybusinesscentral.model.account.account(
                            id = '', 
                            number = '', 
                            display_name = '', 
                            category = '', 
                            sub_category = '', 
                            blocked = True, 
                            last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), )
                    ],
                income_statement = [
                    pybusinesscentral.model.income_statement.incomeStatement(
                        line_number = 56, 
                        display = '', 
                        net_change = 1.337, 
                        line_type = '', 
                        indentation = 56, 
                        date_filter = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                    ],
                tax_areas = [
                    pybusinesscentral.model.tax_area.taxArea(
                        id = '', 
                        code = '', 
                        display_name = '', 
                        tax_type = '', 
                        last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                    ],
                sales_quotes = [
                    pybusinesscentral.model.sales_quote.salesQuote(
                        id = '', 
                        number = '', 
                        external_document_number = '', 
                        document_date = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        due_date = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        customer_id = '', 
                        contact_id = '', 
                        customer_number = '', 
                        customer_name = '', 
                        bill_to_name = '', 
                        bill_to_customer_id = '', 
                        bill_to_customer_number = '', 
                        ship_to_name = '', 
                        ship_to_contact = '', 
                        selling_postal_address = pybusinesscentral.model.postaladdresstype.postaladdresstype(
                            street = '', 
                            city = '', 
                            state = '', 
                            country_letter_code = '', 
                            postal_code = '', 
                            customer_financial_details = [
                                pybusinesscentral.model.customer_financial_detail.customerFinancialDetail(
                                    id = '', 
                                    number = '', 
                                    balance = 1.337, 
                                    total_sales_excluding_tax = 1.337, 
                                    overdue_amount = 1.337, )
                                ], 
                            picture = [
                                pybusinesscentral.model.picture.picture(
                                    id = '', 
                                    width = 56, 
                                    height = 56, 
                                    content_type = '', 
                                    content@odata/media_edit_link = '', 
                                    content@odata/media_read_link = '', )
                                ], 
                            default_dimensions = [
                                pybusinesscentral.model.default_dimensions.defaultDimensions(
                                    parent_id = '', 
                                    dimension_id = '', 
                                    dimension_code = '', 
                                    dimension_value_id = '', 
                                    dimension_value_code = '', 
                                    posting_validation = '', 
                                    account = pybusinesscentral.model.account.account(
                                        id = '', 
                                        number = '', 
                                        display_name = '', 
                                        category = '', 
                                        sub_category = '', 
                                        blocked = True, 
                                        last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), 
                                    dimension = pybusinesscentral.model.dimension.dimension(
                                        id = '', 
                                        code = '', 
                                        display_name = '', 
                                        last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                        dimension_values = [
                                            pybusinesscentral.model.dimension_value.dimensionValue(
                                                id = '', 
                                                code = '', 
                                                display_name = '', 
                                                last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                                            ], ), 
                                    dimension_value = pybusinesscentral.model.dimension_value.dimensionValue(
                                        id = '', 
                                        code = '', 
                                        display_name = '', 
                                        last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), )
                                ], 
                            currency = pybusinesscentral.model.currency.currency(
                                id = '', 
                                code = '', 
                                display_name = '', 
                                symbol = '', 
                                amount_decimal_places = '', 
                                amount_rounding_precision = 1.337, 
                                last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), 
                            payment_term = pybusinesscentral.model.payment_term.paymentTerm(
                                id = '', 
                                code = '', 
                                display_name = '', 
                                due_date_calculation = '', 
                                discount_date_calculation = '', 
                                discount_percent = 1.337, 
                                calculate_discount_on_credit_memos = True, 
                                last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), 
                            shipment_method = pybusinesscentral.model.shipment_method.shipmentMethod(
                                id = '', 
                                code = '', 
                                display_name = '', 
                                last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), 
                            payment_method = pybusinesscentral.model.payment_method.paymentMethod(
                                id = '', 
                                code = '', 
                                display_name = '', 
                                last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), ), 
                        billing_postal_address = pybusinesscentral.model.postaladdresstype.postaladdresstype(
                            street = '', 
                            city = '', 
                            state = '', 
                            country_letter_code = '', 
                            postal_code = '', ), 
                        shipping_postal_address = , 
                        currency_id = '', 
                        currency_code = '', 
                        payment_terms_id = '', 
                        shipment_method_id = '', 
                        salesperson = '', 
                        discount_amount = 1.337, 
                        total_amount_excluding_tax = 1.337, 
                        total_tax_amount = 1.337, 
                        total_amount_including_tax = 1.337, 
                        status = '', 
                        sent_date = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        valid_until_date = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        accepted_date = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        phone_number = '', 
                        email = '', 
                        sales_quote_lines = [
                            pybusinesscentral.model.sales_quote_line.salesQuoteLine(
                                id = '', 
                                document_id = '', 
                                sequence = 56, 
                                item_id = '', 
                                account_id = '', 
                                line_type = '', 
                                line_details = pybusinesscentral.model.documentlineobjectdetailstype.documentlineobjectdetailstype(
                                    number = '', 
                                    display_name = '', 
                                    item = pybusinesscentral.model.item.item(
                                        id = '', 
                                        number = '', 
                                        display_name = '', 
                                        type = '', 
                                        item_category_id = '', 
                                        item_category_code = '', 
                                        blocked = True, 
                                        base_unit_of_measure_id = '', 
                                        base_unit_of_measure = pybusinesscentral.model.unitofmeasuretype.unitofmeasuretype(
                                            code = '', 
                                            display_name = '', 
                                            symbol = '', 
                                            unit_conversion = pybusinesscentral.model.itemunitofmeasureconversiontype.itemunitofmeasureconversiontype(
                                                to_unit_of_measure = '', 
                                                from_to_conversion_rate = 1.337, 
                                                item_category = pybusinesscentral.model.item_category.itemCategory(
                                                    id = '', 
                                                    code = '', 
                                                    display_name = '', 
                                                    last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), ), 
                                            item_category = pybusinesscentral.model.item_category.itemCategory(
                                                id = '', 
                                                code = '', 
                                                display_name = '', 
                                                last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), ), 
                                        gtin = '', 
                                        inventory = 1.337, 
                                        unit_price = 1.337, 
                                        price_includes_tax = True, 
                                        unit_cost = 1.337, 
                                        tax_group_id = '', 
                                        tax_group_code = '', 
                                        last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                        item_category = , ), ), 
                                description = '', 
                                unit_of_measure_id = '', 
                                unit_of_measure = pybusinesscentral.model.unitofmeasuretype.unitofmeasuretype(
                                    code = '', 
                                    display_name = '', 
                                    symbol = '', ), 
                                unit_price = 1.337, 
                                quantity = 1.337, 
                                discount_amount = 1.337, 
                                discount_percent = 1.337, 
                                discount_applied_before_tax = True, 
                                amount_excluding_tax = 1.337, 
                                tax_code = '', 
                                tax_percent = 1.337, 
                                total_tax_amount = 1.337, 
                                amount_including_tax = 1.337, 
                                net_amount = 1.337, 
                                net_tax_amount = 1.337, 
                                net_amount_including_tax = 1.337, 
                                item = pybusinesscentral.model.item.item(
                                    id = '', 
                                    number = '', 
                                    display_name = '', 
                                    type = '', 
                                    item_category_id = '', 
                                    item_category_code = '', 
                                    blocked = True, 
                                    base_unit_of_measure_id = '', 
                                    gtin = '', 
                                    inventory = 1.337, 
                                    unit_price = 1.337, 
                                    price_includes_tax = True, 
                                    unit_cost = 1.337, 
                                    tax_group_id = '', 
                                    tax_group_code = '', 
                                    last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), )
                            ], 
                        pdf_document = [
                            pybusinesscentral.model.pdf_document.pdfDocument(
                                id = '', 
                                content = bytes(b'blah'), )
                            ], 
                        customer = pybusinesscentral.model.customer.customer(
                            id = '', 
                            number = '', 
                            display_name = '', 
                            type = '', 
                            address_line1 = '', 
                            address_line2 = '', 
                            city = '', 
                            state = '', 
                            country = '', 
                            postal_code = '', 
                            phone_number = '', 
                            email = '', 
                            website = '', 
                            tax_liable = True, 
                            tax_area_id = '', 
                            tax_area_display_name = '', 
                            tax_registration_number = '', 
                            currency_id = '', 
                            currency_code = '', 
                            payment_terms_id = '', 
                            shipment_method_id = '', 
                            payment_method_id = '', 
                            blocked = '', 
                            last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), 
                        currency = pybusinesscentral.model.currency.currency(
                            id = '', 
                            code = '', 
                            display_name = '', 
                            symbol = '', 
                            amount_decimal_places = '', 
                            amount_rounding_precision = 1.337, 
                            last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), 
                        payment_term = pybusinesscentral.model.payment_term.paymentTerm(
                            id = '', 
                            code = '', 
                            display_name = '', 
                            due_date_calculation = '', 
                            discount_date_calculation = '', 
                            discount_percent = 1.337, 
                            calculate_discount_on_credit_memos = True, 
                            last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), 
                        shipment_method = pybusinesscentral.model.shipment_method.shipmentMethod(
                            id = '', 
                            code = '', 
                            display_name = '', 
                            last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), )
                    ],
                sales_quote_lines = [
                    pybusinesscentral.model.sales_quote_line.salesQuoteLine(
                        id = '', 
                        document_id = '', 
                        sequence = 56, 
                        item_id = '', 
                        account_id = '', 
                        line_type = '', 
                        line_details = pybusinesscentral.model.documentlineobjectdetailstype.documentlineobjectdetailstype(
                            number = '', 
                            display_name = '', 
                            item = pybusinesscentral.model.item.item(
                                id = '', 
                                number = '', 
                                display_name = '', 
                                type = '', 
                                item_category_id = '', 
                                item_category_code = '', 
                                blocked = True, 
                                base_unit_of_measure_id = '', 
                                base_unit_of_measure = pybusinesscentral.model.unitofmeasuretype.unitofmeasuretype(
                                    code = '', 
                                    display_name = '', 
                                    symbol = '', 
                                    unit_conversion = pybusinesscentral.model.itemunitofmeasureconversiontype.itemunitofmeasureconversiontype(
                                        to_unit_of_measure = '', 
                                        from_to_conversion_rate = 1.337, 
                                        picture = [
                                            pybusinesscentral.model.picture.picture(
                                                id = '', 
                                                width = 56, 
                                                height = 56, 
                                                content_type = '', 
                                                content@odata/media_edit_link = '', 
                                                content@odata/media_read_link = '', )
                                            ], 
                                        default_dimensions = [
                                            pybusinesscentral.model.default_dimensions.defaultDimensions(
                                                parent_id = '', 
                                                dimension_id = '', 
                                                dimension_code = '', 
                                                dimension_value_id = '', 
                                                dimension_value_code = '', 
                                                posting_validation = '', 
                                                account = pybusinesscentral.model.account.account(
                                                    id = '', 
                                                    number = '', 
                                                    display_name = '', 
                                                    category = '', 
                                                    sub_category = '', 
                                                    blocked = True, 
                                                    last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), 
                                                dimension = pybusinesscentral.model.dimension.dimension(
                                                    id = '', 
                                                    code = '', 
                                                    display_name = '', 
                                                    last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                    dimension_values = [
                                                        pybusinesscentral.model.dimension_value.dimensionValue(
                                                            id = '', 
                                                            code = '', 
                                                            display_name = '', 
                                                            last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                                                        ], ), 
                                                dimension_value = pybusinesscentral.model.dimension_value.dimensionValue(
                                                    id = '', 
                                                    code = '', 
                                                    display_name = '', 
                                                    last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), )
                                            ], 
                                        item_category = pybusinesscentral.model.item_category.itemCategory(
                                            id = '', 
                                            code = '', 
                                            display_name = '', 
                                            last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), ), 
                                    picture = [
                                        pybusinesscentral.model.picture.picture(
                                            id = '', 
                                            width = 56, 
                                            height = 56, 
                                            content_type = '', 
                                            content@odata/media_edit_link = '', 
                                            content@odata/media_read_link = '', )
                                        ], 
                                    default_dimensions = [
                                        pybusinesscentral.model.default_dimensions.defaultDimensions(
                                            parent_id = '', 
                                            dimension_id = '', 
                                            dimension_code = '', 
                                            dimension_value_id = '', 
                                            dimension_value_code = '', 
                                            posting_validation = '', )
                                        ], 
                                    item_category = pybusinesscentral.model.item_category.itemCategory(
                                        id = '', 
                                        code = '', 
                                        display_name = '', 
                                        last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), ), 
                                gtin = '', 
                                inventory = 1.337, 
                                unit_price = 1.337, 
                                price_includes_tax = True, 
                                unit_cost = 1.337, 
                                tax_group_id = '', 
                                tax_group_code = '', 
                                last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                picture = , 
                                default_dimensions = , 
                                item_category = , ), 
                            account = pybusinesscentral.model.account.account(
                                id = '', 
                                number = '', 
                                display_name = '', 
                                category = '', 
                                sub_category = '', 
                                blocked = True, 
                                last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), ), 
                        description = '', 
                        unit_of_measure_id = '', 
                        unit_of_measure = pybusinesscentral.model.unitofmeasuretype.unitofmeasuretype(
                            code = '', 
                            display_name = '', 
                            symbol = '', ), 
                        unit_price = 1.337, 
                        quantity = 1.337, 
                        discount_amount = 1.337, 
                        discount_percent = 1.337, 
                        discount_applied_before_tax = True, 
                        amount_excluding_tax = 1.337, 
                        tax_code = '', 
                        tax_percent = 1.337, 
                        total_tax_amount = 1.337, 
                        amount_including_tax = 1.337, 
                        net_amount = 1.337, 
                        net_tax_amount = 1.337, 
                        net_amount_including_tax = 1.337, 
                        item = pybusinesscentral.model.item.item(
                            id = '', 
                            number = '', 
                            display_name = '', 
                            type = '', 
                            item_category_id = '', 
                            item_category_code = '', 
                            blocked = True, 
                            base_unit_of_measure_id = '', 
                            gtin = '', 
                            inventory = 1.337, 
                            unit_price = 1.337, 
                            price_includes_tax = True, 
                            unit_cost = 1.337, 
                            tax_group_id = '', 
                            tax_group_code = '', 
                            last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), 
                        account = , )
                    ],
                sales_credit_memos = [
                    pybusinesscentral.model.sales_credit_memo.salesCreditMemo(
                        id = '', 
                        number = '', 
                        external_document_number = '', 
                        credit_memo_date = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        due_date = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        customer_id = '', 
                        contact_id = '', 
                        customer_number = '', 
                        customer_name = '', 
                        bill_to_name = '', 
                        bill_to_customer_id = '', 
                        bill_to_customer_number = '', 
                        selling_postal_address = pybusinesscentral.model.postaladdresstype.postaladdresstype(
                            street = '', 
                            city = '', 
                            state = '', 
                            country_letter_code = '', 
                            postal_code = '', 
                            customer_financial_details = [
                                pybusinesscentral.model.customer_financial_detail.customerFinancialDetail(
                                    id = '', 
                                    number = '', 
                                    balance = 1.337, 
                                    total_sales_excluding_tax = 1.337, 
                                    overdue_amount = 1.337, )
                                ], 
                            picture = [
                                pybusinesscentral.model.picture.picture(
                                    id = '', 
                                    width = 56, 
                                    height = 56, 
                                    content_type = '', 
                                    content@odata/media_edit_link = '', 
                                    content@odata/media_read_link = '', )
                                ], 
                            default_dimensions = [
                                pybusinesscentral.model.default_dimensions.defaultDimensions(
                                    parent_id = '', 
                                    dimension_id = '', 
                                    dimension_code = '', 
                                    dimension_value_id = '', 
                                    dimension_value_code = '', 
                                    posting_validation = '', 
                                    account = pybusinesscentral.model.account.account(
                                        id = '', 
                                        number = '', 
                                        display_name = '', 
                                        category = '', 
                                        sub_category = '', 
                                        blocked = True, 
                                        last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), 
                                    dimension = pybusinesscentral.model.dimension.dimension(
                                        id = '', 
                                        code = '', 
                                        display_name = '', 
                                        last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                        dimension_values = [
                                            pybusinesscentral.model.dimension_value.dimensionValue(
                                                id = '', 
                                                code = '', 
                                                display_name = '', 
                                                last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                                            ], ), 
                                    dimension_value = pybusinesscentral.model.dimension_value.dimensionValue(
                                        id = '', 
                                        code = '', 
                                        display_name = '', 
                                        last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), )
                                ], 
                            currency = pybusinesscentral.model.currency.currency(
                                id = '', 
                                code = '', 
                                display_name = '', 
                                symbol = '', 
                                amount_decimal_places = '', 
                                amount_rounding_precision = 1.337, 
                                last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), 
                            payment_term = pybusinesscentral.model.payment_term.paymentTerm(
                                id = '', 
                                code = '', 
                                display_name = '', 
                                due_date_calculation = '', 
                                discount_date_calculation = '', 
                                discount_percent = 1.337, 
                                calculate_discount_on_credit_memos = True, 
                                last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), 
                            shipment_method = pybusinesscentral.model.shipment_method.shipmentMethod(
                                id = '', 
                                code = '', 
                                display_name = '', 
                                last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), 
                            payment_method = pybusinesscentral.model.payment_method.paymentMethod(
                                id = '', 
                                code = '', 
                                display_name = '', 
                                last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), ), 
                        billing_postal_address = pybusinesscentral.model.postaladdresstype.postaladdresstype(
                            street = '', 
                            city = '', 
                            state = '', 
                            country_letter_code = '', 
                            postal_code = '', ), 
                        currency_id = '', 
                        currency_code = '', 
                        payment_terms_id = '', 
                        shipment_method_id = '', 
                        salesperson = '', 
                        prices_include_tax = True, 
                        discount_amount = 1.337, 
                        discount_applied_before_tax = True, 
                        total_amount_excluding_tax = 1.337, 
                        total_tax_amount = 1.337, 
                        total_amount_including_tax = 1.337, 
                        status = '', 
                        last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        invoice_id = '', 
                        invoice_number = '', 
                        phone_number = '', 
                        email = '', 
                        sales_credit_memo_lines = [
                            pybusinesscentral.model.sales_credit_memo_line.salesCreditMemoLine(
                                id = '', 
                                document_id = '', 
                                sequence = 56, 
                                item_id = '', 
                                account_id = '', 
                                line_type = '', 
                                line_details = pybusinesscentral.model.documentlineobjectdetailstype.documentlineobjectdetailstype(
                                    number = '', 
                                    display_name = '', 
                                    item = pybusinesscentral.model.item.item(
                                        id = '', 
                                        number = '', 
                                        display_name = '', 
                                        type = '', 
                                        item_category_id = '', 
                                        item_category_code = '', 
                                        blocked = True, 
                                        base_unit_of_measure_id = '', 
                                        base_unit_of_measure = pybusinesscentral.model.unitofmeasuretype.unitofmeasuretype(
                                            code = '', 
                                            display_name = '', 
                                            symbol = '', 
                                            unit_conversion = pybusinesscentral.model.itemunitofmeasureconversiontype.itemunitofmeasureconversiontype(
                                                to_unit_of_measure = '', 
                                                from_to_conversion_rate = 1.337, 
                                                item_category = pybusinesscentral.model.item_category.itemCategory(
                                                    id = '', 
                                                    code = '', 
                                                    display_name = '', 
                                                    last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), ), 
                                            item_category = pybusinesscentral.model.item_category.itemCategory(
                                                id = '', 
                                                code = '', 
                                                display_name = '', 
                                                last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), ), 
                                        gtin = '', 
                                        inventory = 1.337, 
                                        unit_price = 1.337, 
                                        price_includes_tax = True, 
                                        unit_cost = 1.337, 
                                        tax_group_id = '', 
                                        tax_group_code = '', 
                                        last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                        item_category = , ), ), 
                                description = '', 
                                unit_of_measure_id = '', 
                                unit_of_measure = pybusinesscentral.model.unitofmeasuretype.unitofmeasuretype(
                                    code = '', 
                                    display_name = '', 
                                    symbol = '', ), 
                                unit_price = 1.337, 
                                quantity = 1.337, 
                                discount_amount = 1.337, 
                                discount_percent = 1.337, 
                                discount_applied_before_tax = True, 
                                amount_excluding_tax = 1.337, 
                                tax_code = '', 
                                tax_percent = 1.337, 
                                total_tax_amount = 1.337, 
                                amount_including_tax = 1.337, 
                                invoice_discount_allocation = 1.337, 
                                net_amount = 1.337, 
                                net_tax_amount = 1.337, 
                                net_amount_including_tax = 1.337, 
                                shipment_date = datetime.datetime.strptime('1975-12-30', '%Y-%m-%d').date(), 
                                item = pybusinesscentral.model.item.item(
                                    id = '', 
                                    number = '', 
                                    display_name = '', 
                                    type = '', 
                                    item_category_id = '', 
                                    item_category_code = '', 
                                    blocked = True, 
                                    base_unit_of_measure_id = '', 
                                    gtin = '', 
                                    inventory = 1.337, 
                                    unit_price = 1.337, 
                                    price_includes_tax = True, 
                                    unit_cost = 1.337, 
                                    tax_group_id = '', 
                                    tax_group_code = '', 
                                    last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), )
                            ], 
                        pdf_document = [
                            pybusinesscentral.model.pdf_document.pdfDocument(
                                id = '', 
                                content = bytes(b'blah'), )
                            ], 
                        customer = pybusinesscentral.model.customer.customer(
                            id = '', 
                            number = '', 
                            display_name = '', 
                            type = '', 
                            address_line1 = '', 
                            address_line2 = '', 
                            city = '', 
                            state = '', 
                            country = '', 
                            postal_code = '', 
                            phone_number = '', 
                            email = '', 
                            website = '', 
                            tax_liable = True, 
                            tax_area_id = '', 
                            tax_area_display_name = '', 
                            tax_registration_number = '', 
                            currency_id = '', 
                            currency_code = '', 
                            payment_terms_id = '', 
                            shipment_method_id = '', 
                            payment_method_id = '', 
                            blocked = '', 
                            last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), 
                        currency = pybusinesscentral.model.currency.currency(
                            id = '', 
                            code = '', 
                            display_name = '', 
                            symbol = '', 
                            amount_decimal_places = '', 
                            amount_rounding_precision = 1.337, 
                            last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), 
                        payment_term = pybusinesscentral.model.payment_term.paymentTerm(
                            id = '', 
                            code = '', 
                            display_name = '', 
                            due_date_calculation = '', 
                            discount_date_calculation = '', 
                            discount_percent = 1.337, 
                            calculate_discount_on_credit_memos = True, 
                            last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), 
                        shipment_method = pybusinesscentral.model.shipment_method.shipmentMethod(
                            id = '', 
                            code = '', 
                            display_name = '', 
                            last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), )
                    ],
                sales_credit_memo_lines = [
                    pybusinesscentral.model.sales_credit_memo_line.salesCreditMemoLine(
                        id = '', 
                        document_id = '', 
                        sequence = 56, 
                        item_id = '', 
                        account_id = '', 
                        line_type = '', 
                        line_details = pybusinesscentral.model.documentlineobjectdetailstype.documentlineobjectdetailstype(
                            number = '', 
                            display_name = '', 
                            item = pybusinesscentral.model.item.item(
                                id = '', 
                                number = '', 
                                display_name = '', 
                                type = '', 
                                item_category_id = '', 
                                item_category_code = '', 
                                blocked = True, 
                                base_unit_of_measure_id = '', 
                                base_unit_of_measure = pybusinesscentral.model.unitofmeasuretype.unitofmeasuretype(
                                    code = '', 
                                    display_name = '', 
                                    symbol = '', 
                                    unit_conversion = pybusinesscentral.model.itemunitofmeasureconversiontype.itemunitofmeasureconversiontype(
                                        to_unit_of_measure = '', 
                                        from_to_conversion_rate = 1.337, 
                                        picture = [
                                            pybusinesscentral.model.picture.picture(
                                                id = '', 
                                                width = 56, 
                                                height = 56, 
                                                content_type = '', 
                                                content@odata/media_edit_link = '', 
                                                content@odata/media_read_link = '', )
                                            ], 
                                        default_dimensions = [
                                            pybusinesscentral.model.default_dimensions.defaultDimensions(
                                                parent_id = '', 
                                                dimension_id = '', 
                                                dimension_code = '', 
                                                dimension_value_id = '', 
                                                dimension_value_code = '', 
                                                posting_validation = '', 
                                                account = pybusinesscentral.model.account.account(
                                                    id = '', 
                                                    number = '', 
                                                    display_name = '', 
                                                    category = '', 
                                                    sub_category = '', 
                                                    blocked = True, 
                                                    last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), 
                                                dimension = pybusinesscentral.model.dimension.dimension(
                                                    id = '', 
                                                    code = '', 
                                                    display_name = '', 
                                                    last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                    dimension_values = [
                                                        pybusinesscentral.model.dimension_value.dimensionValue(
                                                            id = '', 
                                                            code = '', 
                                                            display_name = '', 
                                                            last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                                                        ], ), 
                                                dimension_value = pybusinesscentral.model.dimension_value.dimensionValue(
                                                    id = '', 
                                                    code = '', 
                                                    display_name = '', 
                                                    last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), )
                                            ], 
                                        item_category = pybusinesscentral.model.item_category.itemCategory(
                                            id = '', 
                                            code = '', 
                                            display_name = '', 
                                            last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), ), 
                                    picture = [
                                        pybusinesscentral.model.picture.picture(
                                            id = '', 
                                            width = 56, 
                                            height = 56, 
                                            content_type = '', 
                                            content@odata/media_edit_link = '', 
                                            content@odata/media_read_link = '', )
                                        ], 
                                    default_dimensions = [
                                        pybusinesscentral.model.default_dimensions.defaultDimensions(
                                            parent_id = '', 
                                            dimension_id = '', 
                                            dimension_code = '', 
                                            dimension_value_id = '', 
                                            dimension_value_code = '', 
                                            posting_validation = '', )
                                        ], 
                                    item_category = pybusinesscentral.model.item_category.itemCategory(
                                        id = '', 
                                        code = '', 
                                        display_name = '', 
                                        last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), ), 
                                gtin = '', 
                                inventory = 1.337, 
                                unit_price = 1.337, 
                                price_includes_tax = True, 
                                unit_cost = 1.337, 
                                tax_group_id = '', 
                                tax_group_code = '', 
                                last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                picture = , 
                                default_dimensions = , 
                                item_category = , ), 
                            account = pybusinesscentral.model.account.account(
                                id = '', 
                                number = '', 
                                display_name = '', 
                                category = '', 
                                sub_category = '', 
                                blocked = True, 
                                last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), ), 
                        description = '', 
                        unit_of_measure_id = '', 
                        unit_of_measure = pybusinesscentral.model.unitofmeasuretype.unitofmeasuretype(
                            code = '', 
                            display_name = '', 
                            symbol = '', ), 
                        unit_price = 1.337, 
                        quantity = 1.337, 
                        discount_amount = 1.337, 
                        discount_percent = 1.337, 
                        discount_applied_before_tax = True, 
                        amount_excluding_tax = 1.337, 
                        tax_code = '', 
                        tax_percent = 1.337, 
                        total_tax_amount = 1.337, 
                        amount_including_tax = 1.337, 
                        invoice_discount_allocation = 1.337, 
                        net_amount = 1.337, 
                        net_tax_amount = 1.337, 
                        net_amount_including_tax = 1.337, 
                        shipment_date = datetime.datetime.strptime('1975-12-30', '%Y-%m-%d').date(), 
                        item = pybusinesscentral.model.item.item(
                            id = '', 
                            number = '', 
                            display_name = '', 
                            type = '', 
                            item_category_id = '', 
                            item_category_code = '', 
                            blocked = True, 
                            base_unit_of_measure_id = '', 
                            gtin = '', 
                            inventory = 1.337, 
                            unit_price = 1.337, 
                            price_includes_tax = True, 
                            unit_cost = 1.337, 
                            tax_group_id = '', 
                            tax_group_code = '', 
                            last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), 
                        account = , )
                    ],
                general_ledger_entry_attachments = [
                    pybusinesscentral.model.general_ledger_entry_attachments.generalLedgerEntryAttachments(
                        general_ledger_entry_number = 56, 
                        id = '', 
                        file_name = '', 
                        byte_size = 56, 
                        content = bytes(b'blah'), 
                        created_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        general_ledger_entry = pybusinesscentral.model.general_ledger_entry.generalLedgerEntry(
                            id = 56, 
                            posting_date = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            document_number = '', 
                            document_type = '', 
                            account_id = '', 
                            account_number = '', 
                            description = '', 
                            debit_amount = 1.337, 
                            credit_amount = 1.337, 
                            dimensions = [
                                null
                                ], 
                            last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            account = pybusinesscentral.model.account.account(
                                id = '', 
                                number = '', 
                                display_name = '', 
                                category = '', 
                                sub_category = '', 
                                blocked = True, 
                                last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), ), )
                    ],
                purchase_invoices = [
                    pybusinesscentral.model.purchase_invoice.purchaseInvoice(
                        id = '', 
                        number = '', 
                        invoice_date = datetime.datetime.strptime('1975-12-30', '%Y-%m-%d').date(), 
                        due_date = datetime.datetime.strptime('1975-12-30', '%Y-%m-%d').date(), 
                        vendor_invoice_number = '', 
                        vendor_id = '', 
                        vendor_number = '', 
                        vendor_name = '', 
                        pay_to_name = '', 
                        pay_to_contact = '', 
                        pay_to_vendor_id = '', 
                        pay_to_vendor_number = '', 
                        ship_to_name = '', 
                        ship_to_contact = '', 
                        buy_from_address = pybusinesscentral.model.postaladdresstype.postaladdresstype(
                            street = '', 
                            city = '', 
                            state = '', 
                            country_letter_code = '', 
                            postal_code = '', 
                            customer_financial_details = [
                                pybusinesscentral.model.customer_financial_detail.customerFinancialDetail(
                                    id = '', 
                                    number = '', 
                                    balance = 1.337, 
                                    total_sales_excluding_tax = 1.337, 
                                    overdue_amount = 1.337, )
                                ], 
                            picture = [
                                pybusinesscentral.model.picture.picture(
                                    id = '', 
                                    width = 56, 
                                    height = 56, 
                                    content_type = '', 
                                    content@odata/media_edit_link = '', 
                                    content@odata/media_read_link = '', )
                                ], 
                            default_dimensions = [
                                pybusinesscentral.model.default_dimensions.defaultDimensions(
                                    parent_id = '', 
                                    dimension_id = '', 
                                    dimension_code = '', 
                                    dimension_value_id = '', 
                                    dimension_value_code = '', 
                                    posting_validation = '', 
                                    account = pybusinesscentral.model.account.account(
                                        id = '', 
                                        number = '', 
                                        display_name = '', 
                                        category = '', 
                                        sub_category = '', 
                                        blocked = True, 
                                        last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), 
                                    dimension = pybusinesscentral.model.dimension.dimension(
                                        id = '', 
                                        code = '', 
                                        display_name = '', 
                                        last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                        dimension_values = [
                                            pybusinesscentral.model.dimension_value.dimensionValue(
                                                id = '', 
                                                code = '', 
                                                display_name = '', 
                                                last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                                            ], ), 
                                    dimension_value = pybusinesscentral.model.dimension_value.dimensionValue(
                                        id = '', 
                                        code = '', 
                                        display_name = '', 
                                        last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), )
                                ], 
                            currency = pybusinesscentral.model.currency.currency(
                                id = '', 
                                code = '', 
                                display_name = '', 
                                symbol = '', 
                                amount_decimal_places = '', 
                                amount_rounding_precision = 1.337, 
                                last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), 
                            payment_term = pybusinesscentral.model.payment_term.paymentTerm(
                                id = '', 
                                code = '', 
                                display_name = '', 
                                due_date_calculation = '', 
                                discount_date_calculation = '', 
                                discount_percent = 1.337, 
                                calculate_discount_on_credit_memos = True, 
                                last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), 
                            shipment_method = pybusinesscentral.model.shipment_method.shipmentMethod(
                                id = '', 
                                code = '', 
                                display_name = '', 
                                last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), 
                            payment_method = pybusinesscentral.model.payment_method.paymentMethod(
                                id = '', 
                                code = '', 
                                display_name = '', 
                                last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), ), 
                        pay_to_address = pybusinesscentral.model.postaladdresstype.postaladdresstype(
                            street = '', 
                            city = '', 
                            state = '', 
                            country_letter_code = '', 
                            postal_code = '', ), 
                        ship_to_address = , 
                        currency_id = '', 
                        currency_code = '', 
                        prices_include_tax = True, 
                        discount_amount = 1.337, 
                        discount_applied_before_tax = True, 
                        total_amount_excluding_tax = 1.337, 
                        total_tax_amount = 1.337, 
                        total_amount_including_tax = 1.337, 
                        status = '', 
                        last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        purchase_invoice_lines = [
                            pybusinesscentral.model.purchase_invoice_line.purchaseInvoiceLine(
                                id = '', 
                                document_id = '', 
                                sequence = 56, 
                                item_id = '', 
                                account_id = '', 
                                line_type = '', 
                                line_details = pybusinesscentral.model.documentlineobjectdetailstype.documentlineobjectdetailstype(
                                    number = '', 
                                    display_name = '', 
                                    item = pybusinesscentral.model.item.item(
                                        id = '', 
                                        number = '', 
                                        display_name = '', 
                                        type = '', 
                                        item_category_id = '', 
                                        item_category_code = '', 
                                        blocked = True, 
                                        base_unit_of_measure_id = '', 
                                        base_unit_of_measure = pybusinesscentral.model.unitofmeasuretype.unitofmeasuretype(
                                            code = '', 
                                            display_name = '', 
                                            symbol = '', 
                                            unit_conversion = pybusinesscentral.model.itemunitofmeasureconversiontype.itemunitofmeasureconversiontype(
                                                to_unit_of_measure = '', 
                                                from_to_conversion_rate = 1.337, 
                                                item_category = pybusinesscentral.model.item_category.itemCategory(
                                                    id = '', 
                                                    code = '', 
                                                    display_name = '', 
                                                    last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), ), 
                                            item_category = pybusinesscentral.model.item_category.itemCategory(
                                                id = '', 
                                                code = '', 
                                                display_name = '', 
                                                last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), ), 
                                        gtin = '', 
                                        inventory = 1.337, 
                                        unit_price = 1.337, 
                                        price_includes_tax = True, 
                                        unit_cost = 1.337, 
                                        tax_group_id = '', 
                                        tax_group_code = '', 
                                        last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                        item_category = , ), ), 
                                description = '', 
                                unit_of_measure = pybusinesscentral.model.unitofmeasuretype.unitofmeasuretype(
                                    code = '', 
                                    display_name = '', 
                                    symbol = '', ), 
                                unit_cost = 1.337, 
                                quantity = 1.337, 
                                discount_amount = 1.337, 
                                discount_percent = 1.337, 
                                discount_applied_before_tax = True, 
                                amount_excluding_tax = 1.337, 
                                tax_code = '', 
                                tax_percent = 1.337, 
                                total_tax_amount = 1.337, 
                                amount_including_tax = 1.337, 
                                invoice_discount_allocation = 1.337, 
                                net_amount = 1.337, 
                                net_tax_amount = 1.337, 
                                net_amount_including_tax = 1.337, 
                                expected_receipt_date = datetime.datetime.strptime('1975-12-30', '%Y-%m-%d').date(), 
                                item = pybusinesscentral.model.item.item(
                                    id = '', 
                                    number = '', 
                                    display_name = '', 
                                    type = '', 
                                    item_category_id = '', 
                                    item_category_code = '', 
                                    blocked = True, 
                                    base_unit_of_measure_id = '', 
                                    gtin = '', 
                                    inventory = 1.337, 
                                    unit_price = 1.337, 
                                    price_includes_tax = True, 
                                    unit_cost = 1.337, 
                                    tax_group_id = '', 
                                    tax_group_code = '', 
                                    last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), )
                            ], 
                        pdf_document = [
                            pybusinesscentral.model.pdf_document.pdfDocument(
                                id = '', 
                                content = bytes(b'blah'), )
                            ], 
                        vendor = pybusinesscentral.model.vendor.vendor(
                            id = '', 
                            number = '', 
                            display_name = '', 
                            address_line1 = '', 
                            address_line2 = '', 
                            city = '', 
                            state = '', 
                            country = '', 
                            postal_code = '', 
                            phone_number = '', 
                            email = '', 
                            website = '', 
                            tax_registration_number = '', 
                            currency_id = '', 
                            currency_code = '', 
                            irs1099_code = '', 
                            payment_terms_id = '', 
                            payment_method_id = '', 
                            tax_liable = True, 
                            blocked = '', 
                            balance = 1.337, 
                            last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), 
                        currency = pybusinesscentral.model.currency.currency(
                            id = '', 
                            code = '', 
                            display_name = '', 
                            symbol = '', 
                            amount_decimal_places = '', 
                            amount_rounding_precision = 1.337, 
                            last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), )
                    ],
                purchase_invoice_lines = [
                    pybusinesscentral.model.purchase_invoice_line.purchaseInvoiceLine(
                        id = '', 
                        document_id = '', 
                        sequence = 56, 
                        item_id = '', 
                        account_id = '', 
                        line_type = '', 
                        line_details = pybusinesscentral.model.documentlineobjectdetailstype.documentlineobjectdetailstype(
                            number = '', 
                            display_name = '', 
                            item = pybusinesscentral.model.item.item(
                                id = '', 
                                number = '', 
                                display_name = '', 
                                type = '', 
                                item_category_id = '', 
                                item_category_code = '', 
                                blocked = True, 
                                base_unit_of_measure_id = '', 
                                base_unit_of_measure = pybusinesscentral.model.unitofmeasuretype.unitofmeasuretype(
                                    code = '', 
                                    display_name = '', 
                                    symbol = '', 
                                    unit_conversion = pybusinesscentral.model.itemunitofmeasureconversiontype.itemunitofmeasureconversiontype(
                                        to_unit_of_measure = '', 
                                        from_to_conversion_rate = 1.337, 
                                        picture = [
                                            pybusinesscentral.model.picture.picture(
                                                id = '', 
                                                width = 56, 
                                                height = 56, 
                                                content_type = '', 
                                                content@odata/media_edit_link = '', 
                                                content@odata/media_read_link = '', )
                                            ], 
                                        default_dimensions = [
                                            pybusinesscentral.model.default_dimensions.defaultDimensions(
                                                parent_id = '', 
                                                dimension_id = '', 
                                                dimension_code = '', 
                                                dimension_value_id = '', 
                                                dimension_value_code = '', 
                                                posting_validation = '', 
                                                account = pybusinesscentral.model.account.account(
                                                    id = '', 
                                                    number = '', 
                                                    display_name = '', 
                                                    category = '', 
                                                    sub_category = '', 
                                                    blocked = True, 
                                                    last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), 
                                                dimension = pybusinesscentral.model.dimension.dimension(
                                                    id = '', 
                                                    code = '', 
                                                    display_name = '', 
                                                    last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                    dimension_values = [
                                                        pybusinesscentral.model.dimension_value.dimensionValue(
                                                            id = '', 
                                                            code = '', 
                                                            display_name = '', 
                                                            last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                                                        ], ), 
                                                dimension_value = pybusinesscentral.model.dimension_value.dimensionValue(
                                                    id = '', 
                                                    code = '', 
                                                    display_name = '', 
                                                    last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), )
                                            ], 
                                        item_category = pybusinesscentral.model.item_category.itemCategory(
                                            id = '', 
                                            code = '', 
                                            display_name = '', 
                                            last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), ), 
                                    picture = [
                                        pybusinesscentral.model.picture.picture(
                                            id = '', 
                                            width = 56, 
                                            height = 56, 
                                            content_type = '', 
                                            content@odata/media_edit_link = '', 
                                            content@odata/media_read_link = '', )
                                        ], 
                                    default_dimensions = [
                                        pybusinesscentral.model.default_dimensions.defaultDimensions(
                                            parent_id = '', 
                                            dimension_id = '', 
                                            dimension_code = '', 
                                            dimension_value_id = '', 
                                            dimension_value_code = '', 
                                            posting_validation = '', )
                                        ], 
                                    item_category = pybusinesscentral.model.item_category.itemCategory(
                                        id = '', 
                                        code = '', 
                                        display_name = '', 
                                        last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), ), 
                                gtin = '', 
                                inventory = 1.337, 
                                unit_price = 1.337, 
                                price_includes_tax = True, 
                                unit_cost = 1.337, 
                                tax_group_id = '', 
                                tax_group_code = '', 
                                last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                picture = , 
                                default_dimensions = , 
                                item_category = , ), 
                            account = pybusinesscentral.model.account.account(
                                id = '', 
                                number = '', 
                                display_name = '', 
                                category = '', 
                                sub_category = '', 
                                blocked = True, 
                                last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), ), 
                        description = '', 
                        unit_of_measure = pybusinesscentral.model.unitofmeasuretype.unitofmeasuretype(
                            code = '', 
                            display_name = '', 
                            symbol = '', ), 
                        unit_cost = 1.337, 
                        quantity = 1.337, 
                        discount_amount = 1.337, 
                        discount_percent = 1.337, 
                        discount_applied_before_tax = True, 
                        amount_excluding_tax = 1.337, 
                        tax_code = '', 
                        tax_percent = 1.337, 
                        total_tax_amount = 1.337, 
                        amount_including_tax = 1.337, 
                        invoice_discount_allocation = 1.337, 
                        net_amount = 1.337, 
                        net_tax_amount = 1.337, 
                        net_amount_including_tax = 1.337, 
                        expected_receipt_date = datetime.datetime.strptime('1975-12-30', '%Y-%m-%d').date(), 
                        item = pybusinesscentral.model.item.item(
                            id = '', 
                            number = '', 
                            display_name = '', 
                            type = '', 
                            item_category_id = '', 
                            item_category_code = '', 
                            blocked = True, 
                            base_unit_of_measure_id = '', 
                            gtin = '', 
                            inventory = 1.337, 
                            unit_price = 1.337, 
                            price_includes_tax = True, 
                            unit_cost = 1.337, 
                            tax_group_id = '', 
                            tax_group_code = '', 
                            last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), 
                        account = , )
                    ],
                projects = [
                    pybusinesscentral.model.project.project(
                        id = '', 
                        number = '', 
                        display_name = '', )
                    ],
                bank_accounts = [
                    pybusinesscentral.model.bank_account.bankAccount(
                        id = '', 
                        number = '', 
                        display_name = '', )
                    ],
                customer_sales = [
                    pybusinesscentral.model.customer_sale.customerSale(
                        customer_id = '', 
                        customer_number = '', 
                        name = '', 
                        total_sales_amount = 1.337, 
                        date_filter_filter_only = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                    ],
                vendor_purchases = [
                    pybusinesscentral.model.vendor_purchase.vendorPurchase(
                        vendor_id = '', 
                        vendor_number = '', 
                        name = '', 
                        total_purchase_amount = 1.337, 
                        date_filter_filter_only = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                    ]
            )
        else:
            return Company(
        )
        """

    def testCompany(self):
        """Test Company"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
